import fastparse
import fastparse.core
import java.lang
import scala
import scala.collection
import scala.collection.immutable
import scala.runtime
import sigmastate
import sigmastate.lang
import sigmastate.lang.exceptions
import sourcecode
import typing



class Basic:
    @staticmethod
    def DecNum() -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    @staticmethod
    def Digit() -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    @staticmethod
    def Exp() -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    @staticmethod
    def FloatType() -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    @staticmethod
    def HexDigit() -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    @staticmethod
    def HexNum() -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    @staticmethod
    def Letter() -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    @staticmethod
    def LetterDigitDollarUnderscore() -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    @staticmethod
    def Lower() -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    @staticmethod
    def Newline() -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    @staticmethod
    def OpChar() -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    @staticmethod
    def Semi() -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    @staticmethod
    def UnicodeEscape() -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    @staticmethod
    def Upper() -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    @staticmethod
    def WSChars() -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    @staticmethod
    def digits() -> java.lang.String: ...
    @typing.overload
    @staticmethod
    def error(msg: typing.Union[java.lang.String, str], srcCtx: scala.Option[sigmastate.lang.SourceContext]) -> scala.runtime.Nothing.: ...
    @typing.overload
    @staticmethod
    def error(msg: typing.Union[java.lang.String, str], srcCtx: sigmastate.lang.SourceContext) -> scala.runtime.Nothing.: ...
    @staticmethod
    def hexDigits() -> java.lang.String: ...
    @staticmethod
    def isOpChar(c: str) -> bool: ...

class Identifiers:
    @staticmethod
    def AlphabetKeywords() -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    @staticmethod
    def BacktickId() -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    @staticmethod
    def Id() -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    @staticmethod
    def IdRest(allowDollar: bool) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    @staticmethod
    def Keywords() -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    @staticmethod
    def NotBackTick() -> 'Identifiers.NamedFunction': ...
    @staticmethod
    def OpCharNotSlash() -> 'Identifiers.NamedFunction': ...
    @staticmethod
    def Operator() -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    @staticmethod
    def PlainId() -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    @staticmethod
    def PlainIdNoDollar() -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    @staticmethod
    def SymbolicKeywords() -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    @staticmethod
    def VarId() -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    @staticmethod
    def VarId0(dollar: bool) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    @staticmethod
    def alphaKeywords() -> scala.collection.Seq[java.lang.String]: ...
    @staticmethod
    def keywords() -> scala.collection.Seq[java.lang.String]: ...
    @staticmethod
    def symbolKeywords() -> scala.collection.Seq[java.lang.String]: ...
    class NamedFunction(scala.Function1[typing.Any, typing.Any], scala.Product, scala.Serializable):
        def __init__(self, f: scala.Function1[typing.Any, typing.Any], name: sourcecode.Name): ...
        _andThen__A = typing.TypeVar('_andThen__A')  # <A>
        def andThen(self, g: scala.Function1[typing.Any, _andThen__A]) -> scala.Function1[typing.Any, _andThen__A]: ...
        def apply(self, t: str) -> bool: ...
        def apply$mcDD$sp(self, v1: float) -> float: ...
        def apply$mcDF$sp(self, v1: float) -> float: ...
        def apply$mcDI$sp(self, v1: int) -> float: ...
        def apply$mcDJ$sp(self, v1: int) -> float: ...
        def apply$mcFD$sp(self, v1: float) -> float: ...
        def apply$mcFF$sp(self, v1: float) -> float: ...
        def apply$mcFI$sp(self, v1: int) -> float: ...
        def apply$mcFJ$sp(self, v1: int) -> float: ...
        def apply$mcID$sp(self, v1: float) -> int: ...
        def apply$mcIF$sp(self, v1: float) -> int: ...
        def apply$mcII$sp(self, v1: int) -> int: ...
        def apply$mcIJ$sp(self, v1: int) -> int: ...
        def apply$mcJD$sp(self, v1: float) -> int: ...
        def apply$mcJF$sp(self, v1: float) -> int: ...
        def apply$mcJI$sp(self, v1: int) -> int: ...
        def apply$mcJJ$sp(self, v1: int) -> int: ...
        def apply$mcVD$sp(self, v1: float) -> None: ...
        def apply$mcVF$sp(self, v1: float) -> None: ...
        def apply$mcVI$sp(self, v1: int) -> None: ...
        def apply$mcVJ$sp(self, v1: int) -> None: ...
        def apply$mcZD$sp(self, v1: float) -> bool: ...
        def apply$mcZF$sp(self, v1: float) -> bool: ...
        def apply$mcZI$sp(self, v1: int) -> bool: ...
        def apply$mcZJ$sp(self, v1: int) -> bool: ...
        def canEqual(self, x$1: typing.Any) -> bool: ...
        _compose__A = typing.TypeVar('_compose__A')  # <A>
        def compose(self, g: scala.Function1[_compose__A, typing.Any]) -> scala.Function1[_compose__A, typing.Any]: ...
        def copy(self, f: scala.Function1[typing.Any, typing.Any], name: sourcecode.Name) -> 'Identifiers.NamedFunction': ...
        def copy$default$1(self) -> scala.Function1[typing.Any, typing.Any]: ...
        def equals(self, x$1: typing.Any) -> bool: ...
        def f(self) -> scala.Function1[typing.Any, typing.Any]: ...
        def hashCode(self) -> int: ...
        def productArity(self) -> int: ...
        def productElement(self, x$1: int) -> typing.Any: ...
        def productIterator(self) -> scala.collection.Iterator[typing.Any]: ...
        def productPrefix(self) -> java.lang.String: ...
        def toString(self) -> java.lang.String: ...
    class NamedFunction$(scala.Serializable):
        MODULE$: typing.ClassVar['Identifiers.NamedFunction.'] = ...
        def __init__(self): ...
        def apply(self, f: scala.Function1[typing.Any, typing.Any], name: sourcecode.Name) -> 'Identifiers.NamedFunction': ...
        def toString(self) -> java.lang.String: ...
        def unapply(self, x$0: 'Identifiers.NamedFunction') -> scala.Option[scala.Function1[typing.Any, typing.Any]]: ...

class Key:
    @staticmethod
    def O(s: typing.Union[java.lang.String, str]) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    @staticmethod
    def W(s: typing.Union[java.lang.String, str]) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...

class ParserException(sigmastate.lang.exceptions.SigmaException):
    def __init__(self, message: typing.Union[java.lang.String, str], source: scala.Option[sigmastate.lang.SourceContext]): ...

_Core__WhitespaceApi2__T = typing.TypeVar('_Core__WhitespaceApi2__T')  # <T>
class Core(sigmastate.lang.syntax.Literals):
    def $at(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    def $colon(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    def $eq(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    def $eq$greater(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    def $greater$colon(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    def $hash(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    @staticmethod
    def $init$($this: 'Core') -> None: ...
    def $less$colon(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    def $times(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    def $u007B(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    def $u007D(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    def BacktickId(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    def ExprLiteral(self) -> fastparse.core.Parser[sigmastate.Values.Constant[sigmastate.SMonoType], typing.Any, java.lang.String]: ...
    def Id(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    def Ids(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    def PatLiteral(self) -> fastparse.core.Parser[sigmastate.Values.Constant[sigmastate.SMonoType], typing.Any, java.lang.String]: ...
    def PostDotCheck(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    def QualId(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    def StableId(self) -> fastparse.core.Parser[sigmastate.Values.Value[sigmastate.SType], typing.Any, java.lang.String]: ...
    def VarId(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    def WhitespaceApi(self) -> 'Core.Wrapper2': ...
    def _(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    def _$times(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    def case(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    def extends(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    def implicit(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    def lazy(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    def match(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    def mkBinaryOp(self, l: sigmastate.Values.Value[sigmastate.SType], opName: typing.Union[java.lang.String, str], r: sigmastate.Values.Value[sigmastate.SType]) -> sigmastate.Values.Value[sigmastate.SType]: ...
    def mkUnaryOp(self, opName: typing.Union[java.lang.String, str], arg: sigmastate.Values.Value[sigmastate.SType]) -> sigmastate.Values.Value[sigmastate.SType]: ...
    def new(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    def sigmastate$lang$syntax$Core$_setter_$$at_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Core$_setter_$$colon_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Core$_setter_$$eq$greater_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Core$_setter_$$eq_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Core$_setter_$$greater$colon_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Core$_setter_$$hash_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Core$_setter_$$less$colon_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Core$_setter_$$times_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Core$_setter_$$u007B_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Core$_setter_$$u007D_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Core$_setter_$BacktickId_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Core$_setter_$ExprLiteral_$eq(self, x$1: fastparse.core.Parser[sigmastate.Values.Constant[sigmastate.SMonoType], typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Core$_setter_$Id_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Core$_setter_$Ids_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Core$_setter_$PatLiteral_$eq(self, x$1: fastparse.core.Parser[sigmastate.Values.Constant[sigmastate.SMonoType], typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Core$_setter_$PostDotCheck_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Core$_setter_$QualId_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Core$_setter_$StableId_$eq(self, x$1: fastparse.core.Parser[sigmastate.Values.Value[sigmastate.SType], typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Core$_setter_$VarId_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Core$_setter_$WhitespaceApi_$eq(self, x$1: 'Core.Wrapper2') -> None: ...
    def sigmastate$lang$syntax$Core$_setter_$_$times_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Core$_setter_$__$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Core$_setter_$case_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Core$_setter_$def_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Core$_setter_$else_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Core$_setter_$extends_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Core$_setter_$if_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Core$_setter_$implicit_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Core$_setter_$lazy_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Core$_setter_$match_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Core$_setter_$new_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Core$_setter_$return_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Core$_setter_$super_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Core$_setter_$then_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Core$_setter_$this_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Core$_setter_$type_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Core$_setter_$val_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Core$_setter_$with_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def super(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    def then(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    def this(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    def type(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    def val(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    class WhitespaceApi2(fastparse.WhitespaceApi[_Core__WhitespaceApi2__T], typing.Generic[_Core__WhitespaceApi2__T]):
        $outer: 'Core' = ...
        def __init__(self, $outer: 'Core', p0: fastparse.core.Parser[_Core__WhitespaceApi2__T, typing.Any, typing.Union[java.lang.String, str]], WL: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]): ...
        _repTC__R = typing.TypeVar('_repTC__R')  # <R>
        def repTC(self, min: int, max: int, exactly: int, ev: fastparse.core.Implicits.Repeater[_Core__WhitespaceApi2__T, _repTC__R]) -> fastparse.core.Parser[_repTC__R, typing.Any, java.lang.String]: ...
        _repTC$default$1__R = typing.TypeVar('_repTC$default$1__R')  # <R>
        def repTC$default$1(self) -> int: ...
        _repTC$default$2__R = typing.TypeVar('_repTC$default$2__R')  # <R>
        def repTC$default$2(self) -> int: ...
        _repTC$default$3__R = typing.TypeVar('_repTC$default$3__R')  # <R>
        def repTC$default$3(self) -> int: ...
    class Wrapper2:
        $outer: 'Core' = ...
        def __init__(self, $outer: 'Core', WL: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]): ...
        _parserApi2__T = typing.TypeVar('_parserApi2__T')  # <T>
        _parserApi2__V = typing.TypeVar('_parserApi2__V')  # <V>
        def parserApi2(self, p0: _parserApi2__T, c: scala.Function1[_parserApi2__T, fastparse.core.Parser[_parserApi2__V, typing.Any, typing.Union[java.lang.String, str]]]) -> 'Core.WhitespaceApi2'[_parserApi2__V]: ...

class Exprs(sigmastate.lang.Types):
    @staticmethod
    def $init$($this: 'Exprs') -> None: ...
    def AnonTmpl(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    def ArgList(self) -> fastparse.core.Parser[sigmastate.Values.Value[sigmastate.SType], typing.Any, java.lang.String]: ...
    def BaseBlock(self, end: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]], name: sourcecode.Name) -> fastparse.core.Parser[sigmastate.Values.Value[sigmastate.SType], typing.Any, java.lang.String]: ...
    def BindPattern(self) -> fastparse.core.Parser[typing.Any, typing.Any, java.lang.String]: ...
    def Block(self) -> fastparse.core.Parser[sigmastate.Values.Value[sigmastate.SType], typing.Any, java.lang.String]: ...
    def BlockChunk(self) -> fastparse.core.Parser[scala.Tuple2[scala.collection.Seq[scala.collection.Seq[scala.Tuple2[java.lang.String, sigmastate.SType]]], scala.collection.Seq[sigmastate.Values.Value[sigmastate.SType]]], typing.Any, java.lang.String]: ...
    def BlockDef(self) -> fastparse.core.Parser[sigmastate.Values.Value[sigmastate.SType], typing.Any, java.lang.String]: ...
    def BlockExpr(self) -> fastparse.core.Parser[sigmastate.Values.Value[sigmastate.SType], typing.Any, java.lang.String]: ...
    def BlockLambda(self) -> fastparse.core.Parser[scala.collection.Seq[scala.Tuple2[java.lang.String, sigmastate.SType]], typing.Any, java.lang.String]: ...
    def BlockLambdaHead(self) -> fastparse.core.Parser[scala.collection.Seq[scala.Tuple2[java.lang.String, sigmastate.SType]], typing.Any, java.lang.String]: ...
    def CaseBlock(self) -> fastparse.core.Parser[sigmastate.Values.Value[sigmastate.SType], typing.Any, java.lang.String]: ...
    def CaseClauses(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    def ExprCtx(self) -> 'Exprs.ExprCtx.': ...
    def FreeCtx(self) -> 'Exprs.FreeCtx.': ...
    def FunDef(self) -> fastparse.core.Parser[sigmastate.lang.Terms.Val, typing.Any, java.lang.String]: ...
    def ParenArgList(self) -> fastparse.core.Parser[sigmastate.Values.Value[sigmastate.SType], typing.Any, java.lang.String]: ...
    def Pattern(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    def Patterns(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    def SimplePattern(self) -> fastparse.core.Parser[typing.Any, typing.Any, java.lang.String]: ...
    def StatCtx(self) -> 'Exprs.StatCtx.': ...
    def TypeExpr(self) -> fastparse.core.Parser[sigmastate.Values.Value[sigmastate.SType], typing.Any, java.lang.String]: ...
    def TypeOrBindPattern(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    def TypePat(self) -> fastparse.core.Parser[sigmastate.SType, typing.Any, java.lang.String]: ...
    def TypePattern(self) -> fastparse.core.Parser[sigmastate.SType, typing.Any, java.lang.String]: ...
    def applySuffix(self, f: sigmastate.Values.Value[sigmastate.SType], args: scala.collection.Seq[sigmastate.SigmaNode]) -> sigmastate.Values.Value[sigmastate.SType]: ...
    def block(self, stats: scala.collection.Seq[sigmastate.Values.Value[sigmastate.SType]]) -> sigmastate.Values.Value[sigmastate.SType]: ...
    def extractBlockStats(self, stats: scala.collection.Seq[sigmastate.Values.Value[sigmastate.SType]]) -> scala.Tuple2[scala.collection.Seq[sigmastate.lang.Terms.Val], sigmastate.Values.Value[sigmastate.SType]]: ...
    def mkInfixTree(self, lhs: sigmastate.Values.Value[sigmastate.SType], rhss: scala.collection.Seq[scala.Tuple2[typing.Union[java.lang.String, str], sigmastate.Values.Value[sigmastate.SType]]]) -> sigmastate.Values.Value[sigmastate.SType]: ...
    @typing.overload
    def precedenceOf(self, ch: str) -> int: ...
    @typing.overload
    def precedenceOf(self, op: typing.Union[java.lang.String, str]) -> int: ...
    def priorityList(self) -> scala.collection.Seq[scala.collection.Seq[typing.Any]]: ...
    def priorityMap(self) -> scala.collection.immutable.Map[typing.Any, typing.Any]: ...
    def sigmastate$lang$syntax$Exprs$$predefFuncRegistry(self) -> sigmastate.lang.SigmaPredef.PredefinedFuncRegistry: ...
    def sigmastate$lang$syntax$Exprs$_setter_$ArgList_$eq(self, x$1: fastparse.core.Parser[sigmastate.Values.Value[sigmastate.SType], typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Exprs$_setter_$BindPattern_$eq(self, x$1: fastparse.core.Parser[typing.Any, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Exprs$_setter_$BlockChunk_$eq(self, x$1: fastparse.core.Parser[scala.Tuple2[scala.collection.Seq[scala.collection.Seq[scala.Tuple2[typing.Union[java.lang.String, str], sigmastate.SType]]], scala.collection.Seq[sigmastate.Values.Value[sigmastate.SType]]], typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Exprs$_setter_$BlockExpr_$eq(self, x$1: fastparse.core.Parser[sigmastate.Values.Value[sigmastate.SType], typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Exprs$_setter_$BlockLambdaHead_$eq(self, x$1: fastparse.core.Parser[scala.collection.Seq[scala.Tuple2[typing.Union[java.lang.String, str], sigmastate.SType]], typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Exprs$_setter_$BlockLambda_$eq(self, x$1: fastparse.core.Parser[scala.collection.Seq[scala.Tuple2[typing.Union[java.lang.String, str], sigmastate.SType]], typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Exprs$_setter_$Block_$eq(self, x$1: fastparse.core.Parser[sigmastate.Values.Value[sigmastate.SType], typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Exprs$_setter_$CaseBlock_$eq(self, x$1: fastparse.core.Parser[sigmastate.Values.Value[sigmastate.SType], typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Exprs$_setter_$CaseClauses_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Exprs$_setter_$FunDef_$eq(self, x$1: fastparse.core.Parser[sigmastate.lang.Terms.Val, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Exprs$_setter_$ParenArgList_$eq(self, x$1: fastparse.core.Parser[sigmastate.Values.Value[sigmastate.SType], typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Exprs$_setter_$Pattern_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Exprs$_setter_$Patterns_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Exprs$_setter_$SimplePattern_$eq(self, x$1: fastparse.core.Parser[typing.Any, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Exprs$_setter_$TypeExpr_$eq(self, x$1: fastparse.core.Parser[sigmastate.Values.Value[sigmastate.SType], typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Exprs$_setter_$TypeOrBindPattern_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Exprs$_setter_$TypePat_$eq(self, x$1: fastparse.core.Parser[sigmastate.SType, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Exprs$_setter_$TypePattern_$eq(self, x$1: fastparse.core.Parser[sigmastate.SType, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Exprs$_setter_$priorityList_$eq(self, x$1: scala.collection.Seq[scala.collection.Seq[typing.Any]]) -> None: ...
    def sigmastate$lang$syntax$Exprs$_setter_$priorityMap_$eq(self, x$1: scala.collection.immutable.Map[typing.Any, typing.Any]) -> None: ...
    def sigmastate$lang$syntax$Exprs$_setter_$sigmastate$lang$syntax$Exprs$$predefFuncRegistry_$eq(self, x$1: sigmastate.lang.SigmaPredef.PredefinedFuncRegistry) -> None: ...
    class ExprCtx$(sigmastate.lang.syntax.Exprs.WsCtx):
        def __init__(self, $outer: 'Exprs'): ...
    class FreeCtx$(sigmastate.lang.syntax.Exprs.WsCtx):
        def __init__(self, $outer: 'Exprs'): ...
    class StatCtx$(sigmastate.lang.syntax.Exprs.WsCtx):
        def __init__(self, $outer: 'Exprs'): ...
    class WsCtx:
        $outer: 'Exprs' = ...
        def __init__(self, $outer: 'Exprs', semiInference: bool, arrowTypeAscriptions: bool): ...
        def Ascription(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
        def AscriptionType(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
        def Expr(self) -> fastparse.core.Parser[sigmastate.Values.Value[sigmastate.SType], typing.Any, java.lang.String]: ...
        def ExprPrefix(self) -> fastparse.core.Parser[java.lang.String, typing.Any, java.lang.String]: ...
        def ExprSuffix(self) -> fastparse.core.Parser[scala.collection.Seq[sigmastate.SigmaNode], typing.Any, java.lang.String]: ...
        def Guard(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
        def InfixSuffix(self) -> fastparse.core.Parser[scala.Tuple2[java.lang.String, sigmastate.Values.Value[sigmastate.SType]], typing.Any, java.lang.String]: ...
        def MatchAscriptionSuffix(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
        def NoSemis(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
        def OneSemiMax(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
        def Parened(self) -> fastparse.core.Parser[scala.collection.Seq[sigmastate.Values.Value[sigmastate.SType]], typing.Any, java.lang.String]: ...
        def PostFix(self) -> fastparse.core.Parser[sigmastate.Values.Value[sigmastate.SType], typing.Any, java.lang.String]: ...
        def PostfixExpr(self) -> fastparse.core.Parser[sigmastate.Values.Value[sigmastate.SType], typing.Any, java.lang.String]: ...
        def PostfixSuffix(self) -> fastparse.core.Parser[scala.Tuple2[scala.collection.Seq[scala.Tuple2[java.lang.String, sigmastate.Values.Value[sigmastate.SType]]], scala.Option[sigmastate.Values.Value[sigmastate.SType]]], typing.Any, java.lang.String]: ...
        def PrefixExpr(self) -> fastparse.core.Parser[sigmastate.Values.Value[sigmastate.SType], typing.Any, java.lang.String]: ...
        def SimpleExpr(self) -> fastparse.core.Parser[sigmastate.Values.Value[sigmastate.SType], typing.Any, java.lang.String]: ...
        def SuperPostfixSuffix(self) -> fastparse.core.Parser[scala.Option[sigmastate.Values.Value[sigmastate.SType]], typing.Any, java.lang.String]: ...

_Literals__ParserOps__T = typing.TypeVar('_Literals__ParserOps__T')  # <T>
class Literals:
    @staticmethod
    def $init$($this: 'Literals') -> None: ...
    def Block(self) -> fastparse.core.Parser[sigmastate.Values.Value[sigmastate.SType], typing.Any, java.lang.String]: ...
    def Literals(self) -> 'Literals.Literals.': ...
    def Newline(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    def NotNewline(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    def OneNLMax(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    def Pattern(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    def Semi(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    def Semis(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    def TrailingComma(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    def WL(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    def WL0(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    def WS(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
    _atSrcPos__A = typing.TypeVar('_atSrcPos__A')  # <A>
    def atSrcPos(self, parserIndex: int, thunk: scala.Function0[_atSrcPos__A]) -> _atSrcPos__A: ...
    def builder(self) -> sigmastate.lang.SigmaBuilder: ...
    def sigmastate$lang$syntax$Literals$_setter_$Newline_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Literals$_setter_$NotNewline_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Literals$_setter_$OneNLMax_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Literals$_setter_$Semi_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Literals$_setter_$Semis_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Literals$_setter_$TrailingComma_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Literals$_setter_$WL0_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Literals$_setter_$WL_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Literals$_setter_$WS_$eq(self, x$1: fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]) -> None: ...
    def sigmastate$lang$syntax$Literals$_setter_$builder_$eq(self, x$1: sigmastate.lang.SigmaBuilder) -> None: ...
    def srcCtx(self, parserIndex: int) -> sigmastate.lang.SourceContext: ...
    class Literals$:
        def __init__(self, $outer: 'Literals'): ...
        def Bool(self) -> fastparse.core.Parser[sigmastate.Values.Constant[sigmastate.SBoolean.], typing.Any, java.lang.String]: ...
        def Char(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
        def Comment(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
        def CommentChunk(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
        def Escape(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
        def Expr(self) -> 'Literals.Literals.Expr.': ...
        def Float(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
        def Int(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
        def LineComment(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
        def MultilineComment(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
        def NoInterp(self) -> 'Literals.Literals.NoInterp.': ...
        def Null(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
        def OctalEscape(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
        def Pat(self) -> 'Literals.Literals.Pat.': ...
        def SameLineCharChunks(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
        def Symbol(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
        class Expr$(sigmastate.lang.syntax.Literals.Literals.InterpCtx):
            def __init__(self, $outer: 'Literals.Literals.'): ...
        class InterpCtx:
            $outer: 'Literals.Literals.' = ...
            def __init__(self, $outer: 'Literals.Literals.', interp: scala.Option[fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, typing.Union[java.lang.String, str]]]): ...
            def Interp(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
            def Literal(self) -> fastparse.core.Parser[sigmastate.Values.Constant[sigmastate.SMonoType], typing.Any, java.lang.String]: ...
            def NonTripleQuoteChar(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
            def SingleChars(self, allowSlash: bool) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
            def String(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
            def StringChars(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
            def TQ(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
            def TripleChars(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
            def TripleTail(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...
        class NoInterp$(sigmastate.lang.syntax.Literals.Literals.InterpCtx):
            def __init__(self, $outer: 'Literals.Literals.'): ...
        class Pat$(sigmastate.lang.syntax.Literals.Literals.InterpCtx):
            def __init__(self, $outer: 'Literals.Literals.'): ...
    class ParserOps(typing.Generic[_Literals__ParserOps__T]):
        $outer: 'Literals' = ...
        def __init__(self, $outer: 'Literals', p: fastparse.core.Parser[_Literals__ParserOps__T, typing.Any, typing.Union[java.lang.String, str]]): ...
        def ignore(self) -> fastparse.core.Parser[scala.runtime.BoxedUnit, typing.Any, java.lang.String]: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("sigmastate.lang.syntax")``.

    Basic: typing.Type[Basic]
    Core: typing.Type[Core]
    Exprs: typing.Type[Exprs]
    Identifiers: typing.Type[Identifiers]
    Key: typing.Type[Key]
    Literals: typing.Type[Literals]
    ParserException: typing.Type[ParserException]



import java.lang
import java.util.concurrent
import scala
import scala.collection
import scala.math
import typing



class Deadline(scala.math.Ordered['Deadline'], scala.Product, scala.Serializable):
    def __init__(self, time: 'FiniteDuration'): ...
    def $greater(self, that: typing.Any) -> bool: ...
    def $greater$eq(self, that: typing.Any) -> bool: ...
    def $less(self, that: typing.Any) -> bool: ...
    def $less$eq(self, that: typing.Any) -> bool: ...
    @typing.overload
    def $minus(self, other: 'FiniteDuration') -> 'Deadline': ...
    @typing.overload
    def $minus(self, other: 'Deadline') -> 'FiniteDuration': ...
    def $plus(self, other: 'FiniteDuration') -> 'Deadline': ...
    @staticmethod
    def apply(time: 'FiniteDuration') -> 'Deadline': ...
    def canEqual(self, x$1: typing.Any) -> bool: ...
    def compare(self, other: 'Deadline') -> int: ...
    def compareTo(self, that: typing.Any) -> int: ...
    def copy(self, time: 'FiniteDuration') -> 'Deadline': ...
    def copy$default$1(self) -> 'FiniteDuration': ...
    def equals(self, x$1: typing.Any) -> bool: ...
    def hasTimeLeft(self) -> bool: ...
    def hashCode(self) -> int: ...
    def isOverdue(self) -> bool: ...
    @staticmethod
    def now() -> 'Deadline': ...
    def productArity(self) -> int: ...
    def productElement(self, x$1: int) -> typing.Any: ...
    def productIterator(self) -> scala.collection.Iterator[typing.Any]: ...
    def productPrefix(self) -> java.lang.String: ...
    def time(self) -> 'FiniteDuration': ...
    def timeLeft(self) -> 'FiniteDuration': ...
    def toString(self) -> java.lang.String: ...
    @staticmethod
    def unapply(x$0: 'Deadline') -> scala.Option['FiniteDuration']: ...
    class DeadlineIsOrdered$(scala.math.Ordering['Deadline']):
        MODULE$: typing.ClassVar['Deadline.DeadlineIsOrdered.'] = ...
        def __init__(self): ...
        def compare(self, a: 'Deadline', b: 'Deadline') -> int: ...
        def equiv(self, x: typing.Any, y: typing.Any) -> bool: ...
        def gt(self, x: typing.Any, y: typing.Any) -> bool: ...
        def gteq(self, x: typing.Any, y: typing.Any) -> bool: ...
        def lt(self, x: typing.Any, y: typing.Any) -> bool: ...
        def lteq(self, x: typing.Any, y: typing.Any) -> bool: ...
        def max(self, x: typing.Any, y: typing.Any) -> typing.Any: ...
        def min(self, x: typing.Any, y: typing.Any) -> typing.Any: ...
        def mkOrderingOps(self, lhs: typing.Any) -> scala.math.Ordering.Ops: ...
        _on__U = typing.TypeVar('_on__U')  # <U>
        def on(self, f: scala.Function1[_on__U, 'Deadline']) -> scala.math.Ordering[_on__U]: ...
        def reverse(self) -> scala.math.Ordering['Deadline']: ...
        def tryCompare(self, x: typing.Any, y: typing.Any) -> scala.Some: ...

class Duration(scala.Serializable, scala.math.Ordered['Duration']):
    def __init__(self): ...
    @typing.overload
    def $div(self, divisor: 'Duration') -> float: ...
    @typing.overload
    def $div(self, divisor: float) -> 'Duration': ...
    def $greater(self, that: typing.Any) -> bool: ...
    def $greater$eq(self, that: typing.Any) -> bool: ...
    def $less(self, that: typing.Any) -> bool: ...
    def $less$eq(self, that: typing.Any) -> bool: ...
    def $minus(self, other: 'Duration') -> 'Duration': ...
    def $plus(self, other: 'Duration') -> 'Duration': ...
    def $times(self, factor: float) -> 'Duration': ...
    @staticmethod
    def Inf() -> 'Duration.Infinite': ...
    @staticmethod
    def MinusInf() -> 'Duration.Infinite': ...
    @staticmethod
    def Undefined() -> 'Duration.Infinite': ...
    @staticmethod
    def Zero() -> 'FiniteDuration': ...
    @typing.overload
    @staticmethod
    def apply(length: float, unit: java.util.concurrent.TimeUnit) -> 'Duration': ...
    @typing.overload
    @staticmethod
    def apply(s: typing.Union[java.lang.String, str]) -> 'Duration': ...
    @typing.overload
    @staticmethod
    def apply(length: int, unit: typing.Union[java.lang.String, str]) -> 'FiniteDuration': ...
    @typing.overload
    @staticmethod
    def apply(length: int, unit: java.util.concurrent.TimeUnit) -> 'FiniteDuration': ...
    def compareTo(self, that: typing.Any) -> int: ...
    @typing.overload
    @staticmethod
    def create(length: float, unit: java.util.concurrent.TimeUnit) -> 'Duration': ...
    @typing.overload
    @staticmethod
    def create(s: typing.Union[java.lang.String, str]) -> 'Duration': ...
    @typing.overload
    @staticmethod
    def create(length: int, unit: typing.Union[java.lang.String, str]) -> 'FiniteDuration': ...
    @typing.overload
    @staticmethod
    def create(length: int, unit: java.util.concurrent.TimeUnit) -> 'FiniteDuration': ...
    @typing.overload
    def div(self, other: 'Duration') -> float: ...
    @typing.overload
    def div(self, divisor: float) -> 'Duration': ...
    @typing.overload
    @staticmethod
    def fromNanos(nanos: float) -> 'Duration': ...
    @typing.overload
    @staticmethod
    def fromNanos(nanos: int) -> 'FiniteDuration': ...
    def gt(self, other: 'Duration') -> bool: ...
    def gteq(self, other: 'Duration') -> bool: ...
    def isFinite(self) -> bool: ...
    def length(self) -> int: ...
    def lt(self, other: 'Duration') -> bool: ...
    def lteq(self, other: 'Duration') -> bool: ...
    def max(self, other: 'Duration') -> 'Duration': ...
    def min(self, other: 'Duration') -> 'Duration': ...
    def minus(self, other: 'Duration') -> 'Duration': ...
    def mul(self, factor: float) -> 'Duration': ...
    def neg(self) -> 'Duration': ...
    def plus(self, other: 'Duration') -> 'Duration': ...
    def toCoarsest(self) -> 'Duration': ...
    def toDays(self) -> int: ...
    def toHours(self) -> int: ...
    def toMicros(self) -> int: ...
    def toMillis(self) -> int: ...
    def toMinutes(self) -> int: ...
    def toNanos(self) -> int: ...
    def toSeconds(self) -> int: ...
    def toUnit(self, unit: java.util.concurrent.TimeUnit) -> float: ...
    @typing.overload
    @staticmethod
    def unapply(s: typing.Union[java.lang.String, str]) -> scala.Option[scala.Tuple2[typing.Any, java.util.concurrent.TimeUnit]]: ...
    @typing.overload
    @staticmethod
    def unapply(d: 'Duration') -> scala.Option[scala.Tuple2[typing.Any, java.util.concurrent.TimeUnit]]: ...
    def unary_$minus(self) -> 'Duration': ...
    def unit(self) -> java.util.concurrent.TimeUnit: ...
    class DurationIsOrdered$(scala.math.Ordering['Duration']):
        MODULE$: typing.ClassVar['Duration.DurationIsOrdered.'] = ...
        def __init__(self): ...
        def compare(self, a: 'Duration', b: 'Duration') -> int: ...
        def equiv(self, x: typing.Any, y: typing.Any) -> bool: ...
        def gt(self, x: typing.Any, y: typing.Any) -> bool: ...
        def gteq(self, x: typing.Any, y: typing.Any) -> bool: ...
        def lt(self, x: typing.Any, y: typing.Any) -> bool: ...
        def lteq(self, x: typing.Any, y: typing.Any) -> bool: ...
        def max(self, x: typing.Any, y: typing.Any) -> typing.Any: ...
        def min(self, x: typing.Any, y: typing.Any) -> typing.Any: ...
        def mkOrderingOps(self, lhs: typing.Any) -> scala.math.Ordering.Ops: ...
        _on__U = typing.TypeVar('_on__U')  # <U>
        def on(self, f: scala.Function1[_on__U, 'Duration']) -> scala.math.Ordering[_on__U]: ...
        def reverse(self) -> scala.math.Ordering['Duration']: ...
        def tryCompare(self, x: typing.Any, y: typing.Any) -> scala.Some: ...
    class Infinite(scala.concurrent.duration.Duration):
        def __init__(self): ...
        @typing.overload
        def $div(self, divisor: 'Duration') -> float: ...
        @typing.overload
        def $div(self, divisor: float) -> 'Duration': ...
        def $minus(self, other: 'Duration') -> 'Duration': ...
        def $plus(self, other: 'Duration') -> 'Duration': ...
        def $times(self, factor: float) -> 'Duration': ...
        def isFinite(self) -> bool: ...
        def length(self) -> int: ...
        def toCoarsest(self) -> 'Duration': ...
        def toDays(self) -> int: ...
        def toHours(self) -> int: ...
        def toMicros(self) -> int: ...
        def toMillis(self) -> int: ...
        def toMinutes(self) -> int: ...
        def toNanos(self) -> int: ...
        def toSeconds(self) -> int: ...
        def unit(self) -> java.util.concurrent.TimeUnit: ...

_DurationConversions__Classifier__C = typing.TypeVar('_DurationConversions__Classifier__C')  # <C>
class DurationConversions:
    @staticmethod
    def $init$($this: 'DurationConversions') -> None: ...
    _day_0__C = typing.TypeVar('_day_0__C')  # <C>
    @typing.overload
    def day(self, c: _day_0__C, ev: 'DurationConversions.Classifier'[_day_0__C]) -> typing.Any: ...
    @typing.overload
    def day(self) -> 'FiniteDuration': ...
    _days_0__C = typing.TypeVar('_days_0__C')  # <C>
    @typing.overload
    def days(self, c: _days_0__C, ev: 'DurationConversions.Classifier'[_days_0__C]) -> typing.Any: ...
    @typing.overload
    def days(self) -> 'FiniteDuration': ...
    def durationIn(self, unit: java.util.concurrent.TimeUnit) -> 'FiniteDuration': ...
    _hour_0__C = typing.TypeVar('_hour_0__C')  # <C>
    @typing.overload
    def hour(self, c: _hour_0__C, ev: 'DurationConversions.Classifier'[_hour_0__C]) -> typing.Any: ...
    @typing.overload
    def hour(self) -> 'FiniteDuration': ...
    _hours_0__C = typing.TypeVar('_hours_0__C')  # <C>
    @typing.overload
    def hours(self, c: _hours_0__C, ev: 'DurationConversions.Classifier'[_hours_0__C]) -> typing.Any: ...
    @typing.overload
    def hours(self) -> 'FiniteDuration': ...
    _micro_0__C = typing.TypeVar('_micro_0__C')  # <C>
    @typing.overload
    def micro(self, c: _micro_0__C, ev: 'DurationConversions.Classifier'[_micro_0__C]) -> typing.Any: ...
    @typing.overload
    def micro(self) -> 'FiniteDuration': ...
    _micros_0__C = typing.TypeVar('_micros_0__C')  # <C>
    @typing.overload
    def micros(self, c: _micros_0__C, ev: 'DurationConversions.Classifier'[_micros_0__C]) -> typing.Any: ...
    @typing.overload
    def micros(self) -> 'FiniteDuration': ...
    _microsecond_0__C = typing.TypeVar('_microsecond_0__C')  # <C>
    @typing.overload
    def microsecond(self, c: _microsecond_0__C, ev: 'DurationConversions.Classifier'[_microsecond_0__C]) -> typing.Any: ...
    @typing.overload
    def microsecond(self) -> 'FiniteDuration': ...
    _microseconds_0__C = typing.TypeVar('_microseconds_0__C')  # <C>
    @typing.overload
    def microseconds(self, c: _microseconds_0__C, ev: 'DurationConversions.Classifier'[_microseconds_0__C]) -> typing.Any: ...
    @typing.overload
    def microseconds(self) -> 'FiniteDuration': ...
    _milli_0__C = typing.TypeVar('_milli_0__C')  # <C>
    @typing.overload
    def milli(self, c: _milli_0__C, ev: 'DurationConversions.Classifier'[_milli_0__C]) -> typing.Any: ...
    @typing.overload
    def milli(self) -> 'FiniteDuration': ...
    _millis_0__C = typing.TypeVar('_millis_0__C')  # <C>
    @typing.overload
    def millis(self, c: _millis_0__C, ev: 'DurationConversions.Classifier'[_millis_0__C]) -> typing.Any: ...
    @typing.overload
    def millis(self) -> 'FiniteDuration': ...
    _millisecond_0__C = typing.TypeVar('_millisecond_0__C')  # <C>
    @typing.overload
    def millisecond(self, c: _millisecond_0__C, ev: 'DurationConversions.Classifier'[_millisecond_0__C]) -> typing.Any: ...
    @typing.overload
    def millisecond(self) -> 'FiniteDuration': ...
    _milliseconds_0__C = typing.TypeVar('_milliseconds_0__C')  # <C>
    @typing.overload
    def milliseconds(self, c: _milliseconds_0__C, ev: 'DurationConversions.Classifier'[_milliseconds_0__C]) -> typing.Any: ...
    @typing.overload
    def milliseconds(self) -> 'FiniteDuration': ...
    _minute_0__C = typing.TypeVar('_minute_0__C')  # <C>
    @typing.overload
    def minute(self, c: _minute_0__C, ev: 'DurationConversions.Classifier'[_minute_0__C]) -> typing.Any: ...
    @typing.overload
    def minute(self) -> 'FiniteDuration': ...
    _minutes_0__C = typing.TypeVar('_minutes_0__C')  # <C>
    @typing.overload
    def minutes(self, c: _minutes_0__C, ev: 'DurationConversions.Classifier'[_minutes_0__C]) -> typing.Any: ...
    @typing.overload
    def minutes(self) -> 'FiniteDuration': ...
    _nano_0__C = typing.TypeVar('_nano_0__C')  # <C>
    @typing.overload
    def nano(self, c: _nano_0__C, ev: 'DurationConversions.Classifier'[_nano_0__C]) -> typing.Any: ...
    @typing.overload
    def nano(self) -> 'FiniteDuration': ...
    _nanos_0__C = typing.TypeVar('_nanos_0__C')  # <C>
    @typing.overload
    def nanos(self, c: _nanos_0__C, ev: 'DurationConversions.Classifier'[_nanos_0__C]) -> typing.Any: ...
    @typing.overload
    def nanos(self) -> 'FiniteDuration': ...
    _nanosecond_0__C = typing.TypeVar('_nanosecond_0__C')  # <C>
    @typing.overload
    def nanosecond(self, c: _nanosecond_0__C, ev: 'DurationConversions.Classifier'[_nanosecond_0__C]) -> typing.Any: ...
    @typing.overload
    def nanosecond(self) -> 'FiniteDuration': ...
    _nanoseconds_0__C = typing.TypeVar('_nanoseconds_0__C')  # <C>
    @typing.overload
    def nanoseconds(self, c: _nanoseconds_0__C, ev: 'DurationConversions.Classifier'[_nanoseconds_0__C]) -> typing.Any: ...
    @typing.overload
    def nanoseconds(self) -> 'FiniteDuration': ...
    _second_0__C = typing.TypeVar('_second_0__C')  # <C>
    @typing.overload
    def second(self, c: _second_0__C, ev: 'DurationConversions.Classifier'[_second_0__C]) -> typing.Any: ...
    @typing.overload
    def second(self) -> 'FiniteDuration': ...
    _seconds_0__C = typing.TypeVar('_seconds_0__C')  # <C>
    @typing.overload
    def seconds(self, c: _seconds_0__C, ev: 'DurationConversions.Classifier'[_seconds_0__C]) -> typing.Any: ...
    @typing.overload
    def seconds(self) -> 'FiniteDuration': ...
    class Classifier(typing.Generic[_DurationConversions__Classifier__C]):
        def convert(self, d: 'FiniteDuration') -> typing.Any: ...
    class fromNowConvert$(scala.concurrent.duration.DurationConversions.Classifier['package.fromNow.']):
        MODULE$: typing.ClassVar['DurationConversions.fromNowConvert.'] = ...
        def __init__(self): ...
        def convert(self, d: 'FiniteDuration') -> Deadline: ...
    class spanConvert$(scala.concurrent.duration.DurationConversions.Classifier['package.span.']):
        MODULE$: typing.ClassVar['DurationConversions.spanConvert.'] = ...
        def __init__(self): ...
        def convert(self, d: 'FiniteDuration') -> 'FiniteDuration': ...

class FiniteDuration(Duration):
    def __init__(self, length: int, unit: java.util.concurrent.TimeUnit): ...
    @typing.overload
    def $div(self, divisor: Duration) -> float: ...
    @typing.overload
    def $div(self, divisor: float) -> Duration: ...
    @typing.overload
    def $div(self, divisor: int) -> 'FiniteDuration': ...
    @typing.overload
    def $minus(self, other: Duration) -> Duration: ...
    @typing.overload
    def $minus(self, other: 'FiniteDuration') -> 'FiniteDuration': ...
    @typing.overload
    def $plus(self, other: Duration) -> Duration: ...
    @typing.overload
    def $plus(self, other: 'FiniteDuration') -> 'FiniteDuration': ...
    @typing.overload
    def $times(self, factor: float) -> Duration: ...
    @typing.overload
    def $times(self, factor: int) -> 'FiniteDuration': ...
    @typing.overload
    @staticmethod
    def apply(length: float, unit: java.util.concurrent.TimeUnit) -> Duration: ...
    @typing.overload
    @staticmethod
    def apply(s: typing.Union[java.lang.String, str]) -> Duration: ...
    @typing.overload
    @staticmethod
    def apply(length: int, unit: typing.Union[java.lang.String, str]) -> 'FiniteDuration': ...
    @typing.overload
    @staticmethod
    def apply(length: int, unit: java.util.concurrent.TimeUnit) -> 'FiniteDuration': ...
    def compare(self, other: Duration) -> int: ...
    @typing.overload
    def div(self, other: Duration) -> float: ...
    @typing.overload
    def div(self, divisor: float) -> Duration: ...
    @typing.overload
    def div(self, divisor: int) -> 'FiniteDuration': ...
    def equals(self, other: typing.Any) -> bool: ...
    def fromNow(self) -> Deadline: ...
    def hashCode(self) -> int: ...
    def isFinite(self) -> bool: ...
    def length(self) -> int: ...
    @typing.overload
    def max(self, other: Duration) -> Duration: ...
    @typing.overload
    def max(self, other: 'FiniteDuration') -> 'FiniteDuration': ...
    @typing.overload
    def min(self, other: Duration) -> Duration: ...
    @typing.overload
    def min(self, other: 'FiniteDuration') -> 'FiniteDuration': ...
    @typing.overload
    def minus(self, other: Duration) -> Duration: ...
    @typing.overload
    def minus(self, other: 'FiniteDuration') -> 'FiniteDuration': ...
    @typing.overload
    def mul(self, factor: float) -> Duration: ...
    @typing.overload
    def mul(self, factor: int) -> 'FiniteDuration': ...
    @typing.overload
    def plus(self, other: Duration) -> Duration: ...
    @typing.overload
    def plus(self, other: 'FiniteDuration') -> 'FiniteDuration': ...
    def toCoarsest(self) -> 'FiniteDuration': ...
    def toDays(self) -> int: ...
    def toHours(self) -> int: ...
    def toMicros(self) -> int: ...
    def toMillis(self) -> int: ...
    def toMinutes(self) -> int: ...
    def toNanos(self) -> int: ...
    def toSeconds(self) -> int: ...
    def toString(self) -> java.lang.String: ...
    def toUnit(self, u: java.util.concurrent.TimeUnit) -> float: ...
    def unary_$minus(self) -> 'FiniteDuration': ...
    def unit(self) -> java.util.concurrent.TimeUnit: ...
    class FiniteDurationIsOrdered$(scala.math.Ordering['FiniteDuration']):
        MODULE$: typing.ClassVar['FiniteDuration.FiniteDurationIsOrdered.'] = ...
        def __init__(self): ...
        def compare(self, a: 'FiniteDuration', b: 'FiniteDuration') -> int: ...
        def equiv(self, x: typing.Any, y: typing.Any) -> bool: ...
        def gt(self, x: typing.Any, y: typing.Any) -> bool: ...
        def gteq(self, x: typing.Any, y: typing.Any) -> bool: ...
        def lt(self, x: typing.Any, y: typing.Any) -> bool: ...
        def lteq(self, x: typing.Any, y: typing.Any) -> bool: ...
        def max(self, x: typing.Any, y: typing.Any) -> typing.Any: ...
        def min(self, x: typing.Any, y: typing.Any) -> typing.Any: ...
        def mkOrderingOps(self, lhs: typing.Any) -> scala.math.Ordering.Ops: ...
        _on__U = typing.TypeVar('_on__U')  # <U>
        def on(self, f: scala.Function1[_on__U, 'FiniteDuration']) -> scala.math.Ordering[_on__U]: ...
        def reverse(self) -> scala.math.Ordering['FiniteDuration']: ...
        def tryCompare(self, x: typing.Any, y: typing.Any) -> scala.Some: ...

class package:
    @staticmethod
    def DAYS() -> java.util.concurrent.TimeUnit: ...
    @staticmethod
    def HOURS() -> java.util.concurrent.TimeUnit: ...
    @staticmethod
    def MICROSECONDS() -> java.util.concurrent.TimeUnit: ...
    @staticmethod
    def MILLISECONDS() -> java.util.concurrent.TimeUnit: ...
    @staticmethod
    def MINUTES() -> java.util.concurrent.TimeUnit: ...
    @staticmethod
    def NANOSECONDS() -> java.util.concurrent.TimeUnit: ...
    @staticmethod
    def SECONDS() -> java.util.concurrent.TimeUnit: ...
    @staticmethod
    def durationToPair(d: Duration) -> scala.Tuple2[typing.Any, java.util.concurrent.TimeUnit]: ...
    @staticmethod
    def pairIntToDuration(p: scala.Tuple2[typing.Any, java.util.concurrent.TimeUnit]) -> Duration: ...
    @staticmethod
    def pairLongToDuration(p: scala.Tuple2[typing.Any, java.util.concurrent.TimeUnit]) -> FiniteDuration: ...
    class DoubleMult:
        def __init__(self, f: float): ...
        def $times(self, d: Duration) -> Duration: ...
        def equals(self, x$1: typing.Any) -> bool: ...
        def hashCode(self) -> int: ...
        def scala$concurrent$duration$DoubleMult$$f(self) -> float: ...
    class DoubleMult$:
        MODULE$: typing.ClassVar['package.DoubleMult.'] = ...
        def __init__(self): ...
        def $times$extension(self, $this: float, d: Duration) -> Duration: ...
        def equals$extension(self, $this: float, x$1: typing.Any) -> bool: ...
        def hashCode$extension(self, $this: float) -> int: ...
    class DurationDouble(DurationConversions):
        def __init__(self, d: float): ...
        _day_0__C = typing.TypeVar('_day_0__C')  # <C>
        @typing.overload
        def day(self, c: _day_0__C, ev: DurationConversions.Classifier[_day_0__C]) -> typing.Any: ...
        @typing.overload
        def day(self) -> FiniteDuration: ...
        _days_0__C = typing.TypeVar('_days_0__C')  # <C>
        @typing.overload
        def days(self, c: _days_0__C, ev: DurationConversions.Classifier[_days_0__C]) -> typing.Any: ...
        @typing.overload
        def days(self) -> FiniteDuration: ...
        def durationIn(self, unit: java.util.concurrent.TimeUnit) -> FiniteDuration: ...
        def equals(self, x$1: typing.Any) -> bool: ...
        def hashCode(self) -> int: ...
        _hour_0__C = typing.TypeVar('_hour_0__C')  # <C>
        @typing.overload
        def hour(self, c: _hour_0__C, ev: DurationConversions.Classifier[_hour_0__C]) -> typing.Any: ...
        @typing.overload
        def hour(self) -> FiniteDuration: ...
        _hours_0__C = typing.TypeVar('_hours_0__C')  # <C>
        @typing.overload
        def hours(self, c: _hours_0__C, ev: DurationConversions.Classifier[_hours_0__C]) -> typing.Any: ...
        @typing.overload
        def hours(self) -> FiniteDuration: ...
        _micro_0__C = typing.TypeVar('_micro_0__C')  # <C>
        @typing.overload
        def micro(self, c: _micro_0__C, ev: DurationConversions.Classifier[_micro_0__C]) -> typing.Any: ...
        @typing.overload
        def micro(self) -> FiniteDuration: ...
        _micros_0__C = typing.TypeVar('_micros_0__C')  # <C>
        @typing.overload
        def micros(self, c: _micros_0__C, ev: DurationConversions.Classifier[_micros_0__C]) -> typing.Any: ...
        @typing.overload
        def micros(self) -> FiniteDuration: ...
        _microsecond_0__C = typing.TypeVar('_microsecond_0__C')  # <C>
        @typing.overload
        def microsecond(self, c: _microsecond_0__C, ev: DurationConversions.Classifier[_microsecond_0__C]) -> typing.Any: ...
        @typing.overload
        def microsecond(self) -> FiniteDuration: ...
        _microseconds_0__C = typing.TypeVar('_microseconds_0__C')  # <C>
        @typing.overload
        def microseconds(self, c: _microseconds_0__C, ev: DurationConversions.Classifier[_microseconds_0__C]) -> typing.Any: ...
        @typing.overload
        def microseconds(self) -> FiniteDuration: ...
        _milli_0__C = typing.TypeVar('_milli_0__C')  # <C>
        @typing.overload
        def milli(self, c: _milli_0__C, ev: DurationConversions.Classifier[_milli_0__C]) -> typing.Any: ...
        @typing.overload
        def milli(self) -> FiniteDuration: ...
        _millis_0__C = typing.TypeVar('_millis_0__C')  # <C>
        @typing.overload
        def millis(self, c: _millis_0__C, ev: DurationConversions.Classifier[_millis_0__C]) -> typing.Any: ...
        @typing.overload
        def millis(self) -> FiniteDuration: ...
        _millisecond_0__C = typing.TypeVar('_millisecond_0__C')  # <C>
        @typing.overload
        def millisecond(self, c: _millisecond_0__C, ev: DurationConversions.Classifier[_millisecond_0__C]) -> typing.Any: ...
        @typing.overload
        def millisecond(self) -> FiniteDuration: ...
        _milliseconds_0__C = typing.TypeVar('_milliseconds_0__C')  # <C>
        @typing.overload
        def milliseconds(self, c: _milliseconds_0__C, ev: DurationConversions.Classifier[_milliseconds_0__C]) -> typing.Any: ...
        @typing.overload
        def milliseconds(self) -> FiniteDuration: ...
        _minute_0__C = typing.TypeVar('_minute_0__C')  # <C>
        @typing.overload
        def minute(self, c: _minute_0__C, ev: DurationConversions.Classifier[_minute_0__C]) -> typing.Any: ...
        @typing.overload
        def minute(self) -> FiniteDuration: ...
        _minutes_0__C = typing.TypeVar('_minutes_0__C')  # <C>
        @typing.overload
        def minutes(self, c: _minutes_0__C, ev: DurationConversions.Classifier[_minutes_0__C]) -> typing.Any: ...
        @typing.overload
        def minutes(self) -> FiniteDuration: ...
        _nano_0__C = typing.TypeVar('_nano_0__C')  # <C>
        @typing.overload
        def nano(self, c: _nano_0__C, ev: DurationConversions.Classifier[_nano_0__C]) -> typing.Any: ...
        @typing.overload
        def nano(self) -> FiniteDuration: ...
        _nanos_0__C = typing.TypeVar('_nanos_0__C')  # <C>
        @typing.overload
        def nanos(self, c: _nanos_0__C, ev: DurationConversions.Classifier[_nanos_0__C]) -> typing.Any: ...
        @typing.overload
        def nanos(self) -> FiniteDuration: ...
        _nanosecond_0__C = typing.TypeVar('_nanosecond_0__C')  # <C>
        @typing.overload
        def nanosecond(self, c: _nanosecond_0__C, ev: DurationConversions.Classifier[_nanosecond_0__C]) -> typing.Any: ...
        @typing.overload
        def nanosecond(self) -> FiniteDuration: ...
        _nanoseconds_0__C = typing.TypeVar('_nanoseconds_0__C')  # <C>
        @typing.overload
        def nanoseconds(self, c: _nanoseconds_0__C, ev: DurationConversions.Classifier[_nanoseconds_0__C]) -> typing.Any: ...
        @typing.overload
        def nanoseconds(self) -> FiniteDuration: ...
        def scala$concurrent$duration$DurationDouble$$d(self) -> float: ...
        _second_0__C = typing.TypeVar('_second_0__C')  # <C>
        @typing.overload
        def second(self, c: _second_0__C, ev: DurationConversions.Classifier[_second_0__C]) -> typing.Any: ...
        @typing.overload
        def second(self) -> FiniteDuration: ...
        _seconds_0__C = typing.TypeVar('_seconds_0__C')  # <C>
        @typing.overload
        def seconds(self, c: _seconds_0__C, ev: DurationConversions.Classifier[_seconds_0__C]) -> typing.Any: ...
        @typing.overload
        def seconds(self) -> FiniteDuration: ...
    class DurationDouble$:
        MODULE$: typing.ClassVar['package.DurationDouble.'] = ...
        def __init__(self): ...
        def durationIn$extension(self, $this: float, unit: java.util.concurrent.TimeUnit) -> FiniteDuration: ...
        def equals$extension(self, $this: float, x$1: typing.Any) -> bool: ...
        def hashCode$extension(self, $this: float) -> int: ...
    class DurationInt(DurationConversions):
        def __init__(self, n: int): ...
        _day_0__C = typing.TypeVar('_day_0__C')  # <C>
        @typing.overload
        def day(self, c: _day_0__C, ev: DurationConversions.Classifier[_day_0__C]) -> typing.Any: ...
        @typing.overload
        def day(self) -> FiniteDuration: ...
        _days_0__C = typing.TypeVar('_days_0__C')  # <C>
        @typing.overload
        def days(self, c: _days_0__C, ev: DurationConversions.Classifier[_days_0__C]) -> typing.Any: ...
        @typing.overload
        def days(self) -> FiniteDuration: ...
        def durationIn(self, unit: java.util.concurrent.TimeUnit) -> FiniteDuration: ...
        def equals(self, x$1: typing.Any) -> bool: ...
        def hashCode(self) -> int: ...
        _hour_0__C = typing.TypeVar('_hour_0__C')  # <C>
        @typing.overload
        def hour(self, c: _hour_0__C, ev: DurationConversions.Classifier[_hour_0__C]) -> typing.Any: ...
        @typing.overload
        def hour(self) -> FiniteDuration: ...
        _hours_0__C = typing.TypeVar('_hours_0__C')  # <C>
        @typing.overload
        def hours(self, c: _hours_0__C, ev: DurationConversions.Classifier[_hours_0__C]) -> typing.Any: ...
        @typing.overload
        def hours(self) -> FiniteDuration: ...
        _micro_0__C = typing.TypeVar('_micro_0__C')  # <C>
        @typing.overload
        def micro(self, c: _micro_0__C, ev: DurationConversions.Classifier[_micro_0__C]) -> typing.Any: ...
        @typing.overload
        def micro(self) -> FiniteDuration: ...
        _micros_0__C = typing.TypeVar('_micros_0__C')  # <C>
        @typing.overload
        def micros(self, c: _micros_0__C, ev: DurationConversions.Classifier[_micros_0__C]) -> typing.Any: ...
        @typing.overload
        def micros(self) -> FiniteDuration: ...
        _microsecond_0__C = typing.TypeVar('_microsecond_0__C')  # <C>
        @typing.overload
        def microsecond(self, c: _microsecond_0__C, ev: DurationConversions.Classifier[_microsecond_0__C]) -> typing.Any: ...
        @typing.overload
        def microsecond(self) -> FiniteDuration: ...
        _microseconds_0__C = typing.TypeVar('_microseconds_0__C')  # <C>
        @typing.overload
        def microseconds(self, c: _microseconds_0__C, ev: DurationConversions.Classifier[_microseconds_0__C]) -> typing.Any: ...
        @typing.overload
        def microseconds(self) -> FiniteDuration: ...
        _milli_0__C = typing.TypeVar('_milli_0__C')  # <C>
        @typing.overload
        def milli(self, c: _milli_0__C, ev: DurationConversions.Classifier[_milli_0__C]) -> typing.Any: ...
        @typing.overload
        def milli(self) -> FiniteDuration: ...
        _millis_0__C = typing.TypeVar('_millis_0__C')  # <C>
        @typing.overload
        def millis(self, c: _millis_0__C, ev: DurationConversions.Classifier[_millis_0__C]) -> typing.Any: ...
        @typing.overload
        def millis(self) -> FiniteDuration: ...
        _millisecond_0__C = typing.TypeVar('_millisecond_0__C')  # <C>
        @typing.overload
        def millisecond(self, c: _millisecond_0__C, ev: DurationConversions.Classifier[_millisecond_0__C]) -> typing.Any: ...
        @typing.overload
        def millisecond(self) -> FiniteDuration: ...
        _milliseconds_0__C = typing.TypeVar('_milliseconds_0__C')  # <C>
        @typing.overload
        def milliseconds(self, c: _milliseconds_0__C, ev: DurationConversions.Classifier[_milliseconds_0__C]) -> typing.Any: ...
        @typing.overload
        def milliseconds(self) -> FiniteDuration: ...
        _minute_0__C = typing.TypeVar('_minute_0__C')  # <C>
        @typing.overload
        def minute(self, c: _minute_0__C, ev: DurationConversions.Classifier[_minute_0__C]) -> typing.Any: ...
        @typing.overload
        def minute(self) -> FiniteDuration: ...
        _minutes_0__C = typing.TypeVar('_minutes_0__C')  # <C>
        @typing.overload
        def minutes(self, c: _minutes_0__C, ev: DurationConversions.Classifier[_minutes_0__C]) -> typing.Any: ...
        @typing.overload
        def minutes(self) -> FiniteDuration: ...
        _nano_0__C = typing.TypeVar('_nano_0__C')  # <C>
        @typing.overload
        def nano(self, c: _nano_0__C, ev: DurationConversions.Classifier[_nano_0__C]) -> typing.Any: ...
        @typing.overload
        def nano(self) -> FiniteDuration: ...
        _nanos_0__C = typing.TypeVar('_nanos_0__C')  # <C>
        @typing.overload
        def nanos(self, c: _nanos_0__C, ev: DurationConversions.Classifier[_nanos_0__C]) -> typing.Any: ...
        @typing.overload
        def nanos(self) -> FiniteDuration: ...
        _nanosecond_0__C = typing.TypeVar('_nanosecond_0__C')  # <C>
        @typing.overload
        def nanosecond(self, c: _nanosecond_0__C, ev: DurationConversions.Classifier[_nanosecond_0__C]) -> typing.Any: ...
        @typing.overload
        def nanosecond(self) -> FiniteDuration: ...
        _nanoseconds_0__C = typing.TypeVar('_nanoseconds_0__C')  # <C>
        @typing.overload
        def nanoseconds(self, c: _nanoseconds_0__C, ev: DurationConversions.Classifier[_nanoseconds_0__C]) -> typing.Any: ...
        @typing.overload
        def nanoseconds(self) -> FiniteDuration: ...
        def scala$concurrent$duration$DurationInt$$n(self) -> int: ...
        _second_0__C = typing.TypeVar('_second_0__C')  # <C>
        @typing.overload
        def second(self, c: _second_0__C, ev: DurationConversions.Classifier[_second_0__C]) -> typing.Any: ...
        @typing.overload
        def second(self) -> FiniteDuration: ...
        _seconds_0__C = typing.TypeVar('_seconds_0__C')  # <C>
        @typing.overload
        def seconds(self, c: _seconds_0__C, ev: DurationConversions.Classifier[_seconds_0__C]) -> typing.Any: ...
        @typing.overload
        def seconds(self) -> FiniteDuration: ...
    class DurationInt$:
        MODULE$: typing.ClassVar['package.DurationInt.'] = ...
        def __init__(self): ...
        def durationIn$extension(self, $this: int, unit: java.util.concurrent.TimeUnit) -> FiniteDuration: ...
        def equals$extension(self, $this: int, x$1: typing.Any) -> bool: ...
        def hashCode$extension(self, $this: int) -> int: ...
    class DurationLong(DurationConversions):
        def __init__(self, n: int): ...
        _day_0__C = typing.TypeVar('_day_0__C')  # <C>
        @typing.overload
        def day(self, c: _day_0__C, ev: DurationConversions.Classifier[_day_0__C]) -> typing.Any: ...
        @typing.overload
        def day(self) -> FiniteDuration: ...
        _days_0__C = typing.TypeVar('_days_0__C')  # <C>
        @typing.overload
        def days(self, c: _days_0__C, ev: DurationConversions.Classifier[_days_0__C]) -> typing.Any: ...
        @typing.overload
        def days(self) -> FiniteDuration: ...
        def durationIn(self, unit: java.util.concurrent.TimeUnit) -> FiniteDuration: ...
        def equals(self, x$1: typing.Any) -> bool: ...
        def hashCode(self) -> int: ...
        _hour_0__C = typing.TypeVar('_hour_0__C')  # <C>
        @typing.overload
        def hour(self, c: _hour_0__C, ev: DurationConversions.Classifier[_hour_0__C]) -> typing.Any: ...
        @typing.overload
        def hour(self) -> FiniteDuration: ...
        _hours_0__C = typing.TypeVar('_hours_0__C')  # <C>
        @typing.overload
        def hours(self, c: _hours_0__C, ev: DurationConversions.Classifier[_hours_0__C]) -> typing.Any: ...
        @typing.overload
        def hours(self) -> FiniteDuration: ...
        _micro_0__C = typing.TypeVar('_micro_0__C')  # <C>
        @typing.overload
        def micro(self, c: _micro_0__C, ev: DurationConversions.Classifier[_micro_0__C]) -> typing.Any: ...
        @typing.overload
        def micro(self) -> FiniteDuration: ...
        _micros_0__C = typing.TypeVar('_micros_0__C')  # <C>
        @typing.overload
        def micros(self, c: _micros_0__C, ev: DurationConversions.Classifier[_micros_0__C]) -> typing.Any: ...
        @typing.overload
        def micros(self) -> FiniteDuration: ...
        _microsecond_0__C = typing.TypeVar('_microsecond_0__C')  # <C>
        @typing.overload
        def microsecond(self, c: _microsecond_0__C, ev: DurationConversions.Classifier[_microsecond_0__C]) -> typing.Any: ...
        @typing.overload
        def microsecond(self) -> FiniteDuration: ...
        _microseconds_0__C = typing.TypeVar('_microseconds_0__C')  # <C>
        @typing.overload
        def microseconds(self, c: _microseconds_0__C, ev: DurationConversions.Classifier[_microseconds_0__C]) -> typing.Any: ...
        @typing.overload
        def microseconds(self) -> FiniteDuration: ...
        _milli_0__C = typing.TypeVar('_milli_0__C')  # <C>
        @typing.overload
        def milli(self, c: _milli_0__C, ev: DurationConversions.Classifier[_milli_0__C]) -> typing.Any: ...
        @typing.overload
        def milli(self) -> FiniteDuration: ...
        _millis_0__C = typing.TypeVar('_millis_0__C')  # <C>
        @typing.overload
        def millis(self, c: _millis_0__C, ev: DurationConversions.Classifier[_millis_0__C]) -> typing.Any: ...
        @typing.overload
        def millis(self) -> FiniteDuration: ...
        _millisecond_0__C = typing.TypeVar('_millisecond_0__C')  # <C>
        @typing.overload
        def millisecond(self, c: _millisecond_0__C, ev: DurationConversions.Classifier[_millisecond_0__C]) -> typing.Any: ...
        @typing.overload
        def millisecond(self) -> FiniteDuration: ...
        _milliseconds_0__C = typing.TypeVar('_milliseconds_0__C')  # <C>
        @typing.overload
        def milliseconds(self, c: _milliseconds_0__C, ev: DurationConversions.Classifier[_milliseconds_0__C]) -> typing.Any: ...
        @typing.overload
        def milliseconds(self) -> FiniteDuration: ...
        _minute_0__C = typing.TypeVar('_minute_0__C')  # <C>
        @typing.overload
        def minute(self, c: _minute_0__C, ev: DurationConversions.Classifier[_minute_0__C]) -> typing.Any: ...
        @typing.overload
        def minute(self) -> FiniteDuration: ...
        _minutes_0__C = typing.TypeVar('_minutes_0__C')  # <C>
        @typing.overload
        def minutes(self, c: _minutes_0__C, ev: DurationConversions.Classifier[_minutes_0__C]) -> typing.Any: ...
        @typing.overload
        def minutes(self) -> FiniteDuration: ...
        _nano_0__C = typing.TypeVar('_nano_0__C')  # <C>
        @typing.overload
        def nano(self, c: _nano_0__C, ev: DurationConversions.Classifier[_nano_0__C]) -> typing.Any: ...
        @typing.overload
        def nano(self) -> FiniteDuration: ...
        _nanos_0__C = typing.TypeVar('_nanos_0__C')  # <C>
        @typing.overload
        def nanos(self, c: _nanos_0__C, ev: DurationConversions.Classifier[_nanos_0__C]) -> typing.Any: ...
        @typing.overload
        def nanos(self) -> FiniteDuration: ...
        _nanosecond_0__C = typing.TypeVar('_nanosecond_0__C')  # <C>
        @typing.overload
        def nanosecond(self, c: _nanosecond_0__C, ev: DurationConversions.Classifier[_nanosecond_0__C]) -> typing.Any: ...
        @typing.overload
        def nanosecond(self) -> FiniteDuration: ...
        _nanoseconds_0__C = typing.TypeVar('_nanoseconds_0__C')  # <C>
        @typing.overload
        def nanoseconds(self, c: _nanoseconds_0__C, ev: DurationConversions.Classifier[_nanoseconds_0__C]) -> typing.Any: ...
        @typing.overload
        def nanoseconds(self) -> FiniteDuration: ...
        def scala$concurrent$duration$DurationLong$$n(self) -> int: ...
        _second_0__C = typing.TypeVar('_second_0__C')  # <C>
        @typing.overload
        def second(self, c: _second_0__C, ev: DurationConversions.Classifier[_second_0__C]) -> typing.Any: ...
        @typing.overload
        def second(self) -> FiniteDuration: ...
        _seconds_0__C = typing.TypeVar('_seconds_0__C')  # <C>
        @typing.overload
        def seconds(self, c: _seconds_0__C, ev: DurationConversions.Classifier[_seconds_0__C]) -> typing.Any: ...
        @typing.overload
        def seconds(self) -> FiniteDuration: ...
    class DurationLong$:
        MODULE$: typing.ClassVar['package.DurationLong.'] = ...
        def __init__(self): ...
        def durationIn$extension(self, $this: int, unit: java.util.concurrent.TimeUnit) -> FiniteDuration: ...
        def equals$extension(self, $this: int, x$1: typing.Any) -> bool: ...
        def hashCode$extension(self, $this: int) -> int: ...
    class IntMult:
        def __init__(self, i: int): ...
        @typing.overload
        def $times(self, d: Duration) -> Duration: ...
        @typing.overload
        def $times(self, d: FiniteDuration) -> FiniteDuration: ...
        def equals(self, x$1: typing.Any) -> bool: ...
        def hashCode(self) -> int: ...
        def scala$concurrent$duration$IntMult$$i(self) -> int: ...
    class IntMult$:
        MODULE$: typing.ClassVar['package.IntMult.'] = ...
        def __init__(self): ...
        def $times$extension0(self, $this: int, d: Duration) -> Duration: ...
        def $times$extension1(self, $this: int, d: FiniteDuration) -> FiniteDuration: ...
        def equals$extension(self, $this: int, x$1: typing.Any) -> bool: ...
        def hashCode$extension(self, $this: int) -> int: ...
    class LongMult:
        def __init__(self, i: int): ...
        @typing.overload
        def $times(self, d: Duration) -> Duration: ...
        @typing.overload
        def $times(self, d: FiniteDuration) -> FiniteDuration: ...
        def equals(self, x$1: typing.Any) -> bool: ...
        def hashCode(self) -> int: ...
        def scala$concurrent$duration$LongMult$$i(self) -> int: ...
    class LongMult$:
        MODULE$: typing.ClassVar['package.LongMult.'] = ...
        def __init__(self): ...
        def $times$extension0(self, $this: int, d: Duration) -> Duration: ...
        def $times$extension1(self, $this: int, d: FiniteDuration) -> FiniteDuration: ...
        def equals$extension(self, $this: int, x$1: typing.Any) -> bool: ...
        def hashCode$extension(self, $this: int) -> int: ...
    class fromNow$:
        MODULE$: typing.ClassVar['package.fromNow.'] = ...
        def __init__(self): ...
    class span$:
        MODULE$: typing.ClassVar['package.span.'] = ...
        def __init__(self): ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("scala.concurrent.duration")``.

    Deadline: typing.Type[Deadline]
    Duration: typing.Type[Duration]
    DurationConversions: typing.Type[DurationConversions]
    FiniteDuration: typing.Type[FiniteDuration]
    package: typing.Type[package]



import datetime
import java.io
import java.lang
import java.time
import java.util
import typing



class ZoneOffsetTransition(java.lang.Comparable['ZoneOffsetTransition'], java.io.Serializable):
    def compareTo(self, zoneOffsetTransition: 'ZoneOffsetTransition') -> int: ...
    def equals(self, object: typing.Any) -> bool: ...
    def getDateTimeAfter(self) -> java.time.LocalDateTime: ...
    def getDateTimeBefore(self) -> java.time.LocalDateTime: ...
    def getDuration(self) -> java.time.Duration: ...
    def getInstant(self) -> java.time.Instant: ...
    def getOffsetAfter(self) -> java.time.ZoneOffset: ...
    def getOffsetBefore(self) -> java.time.ZoneOffset: ...
    def hashCode(self) -> int: ...
    def isGap(self) -> bool: ...
    def isOverlap(self) -> bool: ...
    def isValidOffset(self, zoneOffset: java.time.ZoneOffset) -> bool: ...
    @staticmethod
    def of(localDateTime: java.time.LocalDateTime, zoneOffset: java.time.ZoneOffset, zoneOffset2: java.time.ZoneOffset) -> 'ZoneOffsetTransition': ...
    def toEpochSecond(self) -> int: ...
    def toString(self) -> str: ...

class ZoneOffsetTransitionRule(java.io.Serializable):
    def createTransition(self, int: int) -> ZoneOffsetTransition: ...
    def equals(self, object: typing.Any) -> bool: ...
    def getDayOfMonthIndicator(self) -> int: ...
    def getDayOfWeek(self) -> java.time.DayOfWeek: ...
    def getLocalTime(self) -> java.time.LocalTime: ...
    def getMonth(self) -> java.time.Month: ...
    def getOffsetAfter(self) -> java.time.ZoneOffset: ...
    def getOffsetBefore(self) -> java.time.ZoneOffset: ...
    def getStandardOffset(self) -> java.time.ZoneOffset: ...
    def getTimeDefinition(self) -> 'ZoneOffsetTransitionRule.TimeDefinition': ...
    def hashCode(self) -> int: ...
    def isMidnightEndOfDay(self) -> bool: ...
    @staticmethod
    def of(month: java.time.Month, int: int, dayOfWeek: java.time.DayOfWeek, localTime: java.time.LocalTime, boolean: bool, timeDefinition: 'ZoneOffsetTransitionRule.TimeDefinition', zoneOffset: java.time.ZoneOffset, zoneOffset2: java.time.ZoneOffset, zoneOffset3: java.time.ZoneOffset) -> 'ZoneOffsetTransitionRule': ...
    def toString(self) -> str: ...
    class TimeDefinition(java.lang.Enum['ZoneOffsetTransitionRule.TimeDefinition']):
        UTC: typing.ClassVar['ZoneOffsetTransitionRule.TimeDefinition'] = ...
        WALL: typing.ClassVar['ZoneOffsetTransitionRule.TimeDefinition'] = ...
        STANDARD: typing.ClassVar['ZoneOffsetTransitionRule.TimeDefinition'] = ...
        def createDateTime(self, localDateTime: java.time.LocalDateTime, zoneOffset: java.time.ZoneOffset, zoneOffset2: java.time.ZoneOffset) -> java.time.LocalDateTime: ...
        _valueOf_0__T = typing.TypeVar('_valueOf_0__T', bound=java.lang.Enum)  # <T>
        @typing.overload
        @staticmethod
        def valueOf(class_: typing.Type[_valueOf_0__T], string: str) -> _valueOf_0__T: ...
        @typing.overload
        @staticmethod
        def valueOf(string: str) -> 'ZoneOffsetTransitionRule.TimeDefinition': ...
        @staticmethod
        def values() -> typing.List['ZoneOffsetTransitionRule.TimeDefinition']: ...

class ZoneRules(java.io.Serializable):
    def equals(self, object: typing.Any) -> bool: ...
    def getDaylightSavings(self, instant: typing.Union[java.time.Instant, datetime.datetime]) -> java.time.Duration: ...
    @typing.overload
    def getOffset(self, instant: typing.Union[java.time.Instant, datetime.datetime]) -> java.time.ZoneOffset: ...
    @typing.overload
    def getOffset(self, localDateTime: java.time.LocalDateTime) -> java.time.ZoneOffset: ...
    def getStandardOffset(self, instant: typing.Union[java.time.Instant, datetime.datetime]) -> java.time.ZoneOffset: ...
    def getTransition(self, localDateTime: java.time.LocalDateTime) -> ZoneOffsetTransition: ...
    def getTransitionRules(self) -> java.util.List[ZoneOffsetTransitionRule]: ...
    def getTransitions(self) -> java.util.List[ZoneOffsetTransition]: ...
    def getValidOffsets(self, localDateTime: java.time.LocalDateTime) -> java.util.List[java.time.ZoneOffset]: ...
    def hashCode(self) -> int: ...
    def isDaylightSavings(self, instant: typing.Union[java.time.Instant, datetime.datetime]) -> bool: ...
    def isFixedOffset(self) -> bool: ...
    def isValidOffset(self, localDateTime: java.time.LocalDateTime, zoneOffset: java.time.ZoneOffset) -> bool: ...
    def nextTransition(self, instant: typing.Union[java.time.Instant, datetime.datetime]) -> ZoneOffsetTransition: ...
    @typing.overload
    @staticmethod
    def of(zoneOffset: java.time.ZoneOffset) -> 'ZoneRules': ...
    @typing.overload
    @staticmethod
    def of(zoneOffset: java.time.ZoneOffset, zoneOffset2: java.time.ZoneOffset, list: java.util.List[ZoneOffsetTransition], list2: java.util.List[ZoneOffsetTransition], list3: java.util.List[ZoneOffsetTransitionRule]) -> 'ZoneRules': ...
    def previousTransition(self, instant: typing.Union[java.time.Instant, datetime.datetime]) -> ZoneOffsetTransition: ...
    def toString(self) -> str: ...

class ZoneRulesException(java.time.DateTimeException):
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, throwable: java.lang.Throwable): ...

class ZoneRulesProvider:
    @staticmethod
    def getAvailableZoneIds() -> java.util.Set[str]: ...
    @staticmethod
    def getRules(string: str, boolean: bool) -> ZoneRules: ...
    @staticmethod
    def getVersions(string: str) -> java.util.NavigableMap[str, ZoneRules]: ...
    @staticmethod
    def refresh() -> bool: ...
    @staticmethod
    def registerProvider(zoneRulesProvider: 'ZoneRulesProvider') -> None: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.time.zone")``.

    ZoneOffsetTransition: typing.Type[ZoneOffsetTransition]
    ZoneOffsetTransitionRule: typing.Type[ZoneOffsetTransitionRule]
    ZoneRules: typing.Type[ZoneRules]
    ZoneRulesException: typing.Type[ZoneRulesException]
    ZoneRulesProvider: typing.Type[ZoneRulesProvider]



import java.lang
import java.util
import java.util.concurrent
import scala
import scala.collection
import typing



class package:
    class ForkJoinPool$:
        MODULE$: typing.ClassVar['package.ForkJoinPool.'] = ...
        def __init__(self): ...
        def defaultForkJoinWorkerThreadFactory(self) -> java.util.concurrent.ForkJoinPool.ForkJoinWorkerThreadFactory: ...
        def managedBlock(self, blocker: java.util.concurrent.ForkJoinPool.ManagedBlocker) -> None: ...
    class ForkJoinTask$(scala.Serializable):
        MODULE$: typing.ClassVar['package.ForkJoinTask.'] = ...
        def __init__(self): ...
        _adapt_1__T = typing.TypeVar('_adapt_1__T')  # <T>
        _adapt_2__T = typing.TypeVar('_adapt_2__T')  # <T>
        @typing.overload
        def adapt(self, runnable: typing.Union[java.lang.Runnable, typing.Callable]) -> java.util.concurrent.ForkJoinTask[typing.Any]: ...
        @typing.overload
        def adapt(self, runnable: typing.Union[java.lang.Runnable, typing.Callable], result: _adapt_1__T) -> java.util.concurrent.ForkJoinTask[_adapt_1__T]: ...
        @typing.overload
        def adapt(self, callable: typing.Union[java.util.concurrent.Callable[_adapt_2__T], typing.Callable[[], _adapt_2__T]]) -> java.util.concurrent.ForkJoinTask[_adapt_2__T]: ...
        def getPool(self) -> java.util.concurrent.ForkJoinPool: ...
        def getQueuedTaskCount(self) -> int: ...
        def getSurplusQueuedTaskCount(self) -> int: ...
        def helpQuiesce(self) -> None: ...
        def inForkJoinPool(self) -> bool: ...
        _invokeAll_0__T = typing.TypeVar('_invokeAll_0__T', bound=java.util.concurrent.ForkJoinTask)  # <T>
        _invokeAll_1__T = typing.TypeVar('_invokeAll_1__T')  # <T>
        _invokeAll_2__T = typing.TypeVar('_invokeAll_2__T')  # <T>
        @typing.overload
        def invokeAll(self, tasks: typing.Union[java.util.Collection[_invokeAll_0__T], typing.Sequence[_invokeAll_0__T], typing.Set[_invokeAll_0__T]]) -> java.util.Collection[_invokeAll_0__T]: ...
        @typing.overload
        def invokeAll(self, t1: java.util.concurrent.ForkJoinTask[_invokeAll_1__T]) -> None: ...
        @typing.overload
        def invokeAll(self, tasks: scala.collection.Seq[java.util.concurrent.ForkJoinTask[_invokeAll_2__T]]) -> None: ...
    class ThreadLocalRandom$(scala.Serializable):
        MODULE$: typing.ClassVar['package.ThreadLocalRandom.'] = ...
        def __init__(self): ...
        def current(self) -> java.util.concurrent.ThreadLocalRandom: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("scala.concurrent.forkjoin")``.

    package: typing.Type[package]



import java.lang
import org.ergoplatform
import scala
import scala.collection
import sigmastate.interpreter
import special.collection
import special.sigma
import typing



class ErgoLikeParameters:
    def blockVersion(self) -> int: ...
    def dataInputCost(self) -> int: ...
    def inputCost(self) -> int: ...
    def maxBlockCost(self) -> int: ...
    def maxBlockSize(self) -> int: ...
    def minValuePerByte(self) -> int: ...
    def outputCost(self) -> int: ...
    def softForkStartingHeight(self) -> scala.Option[typing.Any]: ...
    def softForkVotesCollected(self) -> scala.Option[typing.Any]: ...
    def storageFeeFactor(self) -> int: ...
    def tokenAccessCost(self) -> int: ...

class ErgoLikeStateContext:
    def previousStateDigest(self) -> typing.List[int]: ...
    def sigmaLastHeaders(self) -> special.collection.Coll[special.sigma.Header]: ...
    def sigmaPreHeader(self) -> special.sigma.PreHeader: ...

class InputContext(scala.Product, scala.Serializable):
    def __init__(self, selfIndex: int, extension: sigmastate.interpreter.ContextExtension): ...
    @staticmethod
    def apply(selfIndex: int, extension: sigmastate.interpreter.ContextExtension) -> 'InputContext': ...
    def canEqual(self, x$1: typing.Any) -> bool: ...
    def copy(self, selfIndex: int, extension: sigmastate.interpreter.ContextExtension) -> 'InputContext': ...
    def copy$default$1(self) -> int: ...
    def copy$default$2(self) -> sigmastate.interpreter.ContextExtension: ...
    @staticmethod
    def curried() -> scala.Function1[typing.Any, scala.Function1[sigmastate.interpreter.ContextExtension, 'InputContext']]: ...
    def equals(self, x$1: typing.Any) -> bool: ...
    def extension(self) -> sigmastate.interpreter.ContextExtension: ...
    def hashCode(self) -> int: ...
    def productArity(self) -> int: ...
    def productElement(self, x$1: int) -> typing.Any: ...
    def productIterator(self) -> scala.collection.Iterator[typing.Any]: ...
    def productPrefix(self) -> java.lang.String: ...
    def selfIndex(self) -> int: ...
    def toString(self) -> java.lang.String: ...
    @staticmethod
    def tupled() -> scala.Function1[scala.Tuple2[typing.Any, sigmastate.interpreter.ContextExtension], 'InputContext']: ...
    @staticmethod
    def unapply(x$0: 'InputContext') -> scala.Option[scala.Tuple2[typing.Any, sigmastate.interpreter.ContextExtension]]: ...

class TransactionContext(scala.Product, scala.Serializable):
    def __init__(self, boxesToSpend: scala.collection.IndexedSeq[org.ergoplatform.ErgoBox], dataBoxes: scala.collection.IndexedSeq[org.ergoplatform.ErgoBox], spendingTransaction: org.ergoplatform.ErgoLikeTransactionTemplate[org.ergoplatform.UnsignedInput]): ...
    @staticmethod
    def apply(boxesToSpend: scala.collection.IndexedSeq[org.ergoplatform.ErgoBox], dataBoxes: scala.collection.IndexedSeq[org.ergoplatform.ErgoBox], spendingTransaction: org.ergoplatform.ErgoLikeTransactionTemplate[org.ergoplatform.UnsignedInput]) -> 'TransactionContext': ...
    def boxesToSpend(self) -> scala.collection.IndexedSeq[org.ergoplatform.ErgoBox]: ...
    def canEqual(self, x$1: typing.Any) -> bool: ...
    def copy(self, boxesToSpend: scala.collection.IndexedSeq[org.ergoplatform.ErgoBox], dataBoxes: scala.collection.IndexedSeq[org.ergoplatform.ErgoBox], spendingTransaction: org.ergoplatform.ErgoLikeTransactionTemplate[org.ergoplatform.UnsignedInput]) -> 'TransactionContext': ...
    def copy$default$1(self) -> scala.collection.IndexedSeq[org.ergoplatform.ErgoBox]: ...
    def copy$default$2(self) -> scala.collection.IndexedSeq[org.ergoplatform.ErgoBox]: ...
    def copy$default$3(self) -> org.ergoplatform.ErgoLikeTransactionTemplate[org.ergoplatform.UnsignedInput]: ...
    @staticmethod
    def curried() -> scala.Function1[scala.collection.IndexedSeq[org.ergoplatform.ErgoBox], scala.Function1[scala.collection.IndexedSeq[org.ergoplatform.ErgoBox], scala.Function1[org.ergoplatform.ErgoLikeTransactionTemplate[org.ergoplatform.UnsignedInput], 'TransactionContext']]]: ...
    def dataBoxes(self) -> scala.collection.IndexedSeq[org.ergoplatform.ErgoBox]: ...
    def equals(self, x$1: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    def productArity(self) -> int: ...
    def productElement(self, x$1: int) -> typing.Any: ...
    def productIterator(self) -> scala.collection.Iterator[typing.Any]: ...
    def productPrefix(self) -> java.lang.String: ...
    def spendingTransaction(self) -> org.ergoplatform.ErgoLikeTransactionTemplate[org.ergoplatform.UnsignedInput]: ...
    def toString(self) -> java.lang.String: ...
    @staticmethod
    def tupled() -> scala.Function1[scala.Tuple3[scala.collection.IndexedSeq[org.ergoplatform.ErgoBox], scala.collection.IndexedSeq[org.ergoplatform.ErgoBox], org.ergoplatform.ErgoLikeTransactionTemplate[org.ergoplatform.UnsignedInput]], 'TransactionContext']: ...
    @staticmethod
    def unapply(x$0: 'TransactionContext') -> scala.Option[scala.Tuple3[scala.collection.IndexedSeq[org.ergoplatform.ErgoBox], scala.collection.IndexedSeq[org.ergoplatform.ErgoBox], org.ergoplatform.ErgoLikeTransactionTemplate[org.ergoplatform.UnsignedInput]]]: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("org.ergoplatform.wallet.protocol.context")``.

    ErgoLikeParameters: typing.Type[ErgoLikeParameters]
    ErgoLikeStateContext: typing.Type[ErgoLikeStateContext]
    InputContext: typing.Type[InputContext]
    TransactionContext: typing.Type[TransactionContext]



import java.io
import jpype.protocol
import typing



class FileUtils:
    @staticmethod
    def $init$($this: 'FileUtils') -> None: ...
    def createTempDir(self) -> java.io.File: ...
    def createTempFile(self) -> java.io.File: ...
    def deleteRecursive(self, root: typing.Union[java.io.File, jpype.protocol.SupportsPath]) -> None: ...
    def org$ergoplatform$wallet$utils$FileUtils$_setter_$randomPrefixLength_$eq(self, x$1: int) -> None: ...
    def randomPrefixLength(self) -> int: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("org.ergoplatform.wallet.utils")``.

    FileUtils: typing.Type[FileUtils]



import java.io
import java.lang
import java.net
import java.nio
import java.nio.file
import java.util
import java.util.function
import java.util.stream
import typing



class Configuration:
    @staticmethod
    def empty() -> 'Configuration': ...
    def findModule(self, string: str) -> java.util.Optional['ResolvedModule']: ...
    def modules(self) -> java.util.Set['ResolvedModule']: ...
    def parents(self) -> java.util.List['Configuration']: ...
    @typing.overload
    def resolve(self, moduleFinder: 'ModuleFinder', moduleFinder2: 'ModuleFinder', collection: typing.Union[java.util.Collection[str], typing.Sequence[str], typing.Set[str]]) -> 'Configuration': ...
    @typing.overload
    @staticmethod
    def resolve(moduleFinder: 'ModuleFinder', list: java.util.List['Configuration'], moduleFinder2: 'ModuleFinder', collection: typing.Union[java.util.Collection[str], typing.Sequence[str], typing.Set[str]]) -> 'Configuration': ...
    @typing.overload
    def resolveAndBind(self, moduleFinder: 'ModuleFinder', moduleFinder2: 'ModuleFinder', collection: typing.Union[java.util.Collection[str], typing.Sequence[str], typing.Set[str]]) -> 'Configuration': ...
    @typing.overload
    @staticmethod
    def resolveAndBind(moduleFinder: 'ModuleFinder', list: java.util.List['Configuration'], moduleFinder2: 'ModuleFinder', collection: typing.Union[java.util.Collection[str], typing.Sequence[str], typing.Set[str]]) -> 'Configuration': ...
    def toString(self) -> str: ...

class FindException(java.lang.RuntimeException):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, throwable: java.lang.Throwable): ...
    @typing.overload
    def __init__(self, throwable: java.lang.Throwable): ...

class InvalidModuleDescriptorException(java.lang.RuntimeException):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...

class ModuleDescriptor(java.lang.Comparable['ModuleDescriptor']):
    def compareTo(self, moduleDescriptor: 'ModuleDescriptor') -> int: ...
    def equals(self, object: typing.Any) -> bool: ...
    def exports(self) -> java.util.Set['ModuleDescriptor.Exports']: ...
    def hashCode(self) -> int: ...
    def isAutomatic(self) -> bool: ...
    def isOpen(self) -> bool: ...
    def mainClass(self) -> java.util.Optional[str]: ...
    def modifiers(self) -> java.util.Set['ModuleDescriptor.Modifier']: ...
    def name(self) -> str: ...
    @staticmethod
    def newAutomaticModule(string: str) -> 'ModuleDescriptor.Builder': ...
    @typing.overload
    @staticmethod
    def newModule(string: str) -> 'ModuleDescriptor.Builder': ...
    @typing.overload
    @staticmethod
    def newModule(string: str, set: java.util.Set['ModuleDescriptor.Modifier']) -> 'ModuleDescriptor.Builder': ...
    @staticmethod
    def newOpenModule(string: str) -> 'ModuleDescriptor.Builder': ...
    def opens(self) -> java.util.Set['ModuleDescriptor.Opens']: ...
    def packages(self) -> java.util.Set[str]: ...
    def provides(self) -> java.util.Set['ModuleDescriptor.Provides']: ...
    def rawVersion(self) -> java.util.Optional[str]: ...
    @typing.overload
    @staticmethod
    def read(inputStream: java.io.InputStream) -> 'ModuleDescriptor': ...
    @typing.overload
    @staticmethod
    def read(inputStream: java.io.InputStream, supplier: typing.Union[java.util.function.Supplier[java.util.Set[str]], typing.Callable[[], java.util.Set[str]]]) -> 'ModuleDescriptor': ...
    @typing.overload
    @staticmethod
    def read(byteBuffer: java.nio.ByteBuffer) -> 'ModuleDescriptor': ...
    @typing.overload
    @staticmethod
    def read(byteBuffer: java.nio.ByteBuffer, supplier: typing.Union[java.util.function.Supplier[java.util.Set[str]], typing.Callable[[], java.util.Set[str]]]) -> 'ModuleDescriptor': ...
    def requires(self) -> java.util.Set['ModuleDescriptor.Requires']: ...
    def toNameAndVersion(self) -> str: ...
    def toString(self) -> str: ...
    def uses(self) -> java.util.Set[str]: ...
    def version(self) -> java.util.Optional['ModuleDescriptor.Version']: ...
    class Builder:
        def build(self) -> 'ModuleDescriptor': ...
        @typing.overload
        def exports(self, string: str) -> 'ModuleDescriptor.Builder': ...
        @typing.overload
        def exports(self, string: str, set: java.util.Set[str]) -> 'ModuleDescriptor.Builder': ...
        @typing.overload
        def exports(self, exports: 'ModuleDescriptor.Exports') -> 'ModuleDescriptor.Builder': ...
        @typing.overload
        def exports(self, set: java.util.Set['ModuleDescriptor.Exports.Modifier'], string: str) -> 'ModuleDescriptor.Builder': ...
        @typing.overload
        def exports(self, set: java.util.Set['ModuleDescriptor.Exports.Modifier'], string: str, set2: java.util.Set[str]) -> 'ModuleDescriptor.Builder': ...
        def mainClass(self, string: str) -> 'ModuleDescriptor.Builder': ...
        @typing.overload
        def opens(self, string: str) -> 'ModuleDescriptor.Builder': ...
        @typing.overload
        def opens(self, string: str, set: java.util.Set[str]) -> 'ModuleDescriptor.Builder': ...
        @typing.overload
        def opens(self, opens: 'ModuleDescriptor.Opens') -> 'ModuleDescriptor.Builder': ...
        @typing.overload
        def opens(self, set: java.util.Set['ModuleDescriptor.Opens.Modifier'], string: str) -> 'ModuleDescriptor.Builder': ...
        @typing.overload
        def opens(self, set: java.util.Set['ModuleDescriptor.Opens.Modifier'], string: str, set2: java.util.Set[str]) -> 'ModuleDescriptor.Builder': ...
        def packages(self, set: java.util.Set[str]) -> 'ModuleDescriptor.Builder': ...
        @typing.overload
        def provides(self, string: str, list: java.util.List[str]) -> 'ModuleDescriptor.Builder': ...
        @typing.overload
        def provides(self, provides: 'ModuleDescriptor.Provides') -> 'ModuleDescriptor.Builder': ...
        @typing.overload
        def requires(self, string: str) -> 'ModuleDescriptor.Builder': ...
        @typing.overload
        def requires(self, requires: 'ModuleDescriptor.Requires') -> 'ModuleDescriptor.Builder': ...
        @typing.overload
        def requires(self, set: java.util.Set['ModuleDescriptor.Requires.Modifier'], string: str) -> 'ModuleDescriptor.Builder': ...
        @typing.overload
        def requires(self, set: java.util.Set['ModuleDescriptor.Requires.Modifier'], string: str, version: 'ModuleDescriptor.Version') -> 'ModuleDescriptor.Builder': ...
        def uses(self, string: str) -> 'ModuleDescriptor.Builder': ...
        @typing.overload
        def version(self, string: str) -> 'ModuleDescriptor.Builder': ...
        @typing.overload
        def version(self, version: 'ModuleDescriptor.Version') -> 'ModuleDescriptor.Builder': ...
    class Exports(java.lang.Comparable['ModuleDescriptor.Exports']):
        def compareTo(self, exports: 'ModuleDescriptor.Exports') -> int: ...
        def equals(self, object: typing.Any) -> bool: ...
        def hashCode(self) -> int: ...
        def isQualified(self) -> bool: ...
        def modifiers(self) -> java.util.Set['ModuleDescriptor.Exports.Modifier']: ...
        def source(self) -> str: ...
        def targets(self) -> java.util.Set[str]: ...
        def toString(self) -> str: ...
        class Modifier(java.lang.Enum['ModuleDescriptor.Exports.Modifier']):
            SYNTHETIC: typing.ClassVar['ModuleDescriptor.Exports.Modifier'] = ...
            MANDATED: typing.ClassVar['ModuleDescriptor.Exports.Modifier'] = ...
            _valueOf_0__T = typing.TypeVar('_valueOf_0__T', bound=java.lang.Enum)  # <T>
            @typing.overload
            @staticmethod
            def valueOf(class_: typing.Type[_valueOf_0__T], string: str) -> _valueOf_0__T: ...
            @typing.overload
            @staticmethod
            def valueOf(string: str) -> 'ModuleDescriptor.Exports.Modifier': ...
            @staticmethod
            def values() -> typing.List['ModuleDescriptor.Exports.Modifier']: ...
    class Modifier(java.lang.Enum['ModuleDescriptor.Modifier']):
        OPEN: typing.ClassVar['ModuleDescriptor.Modifier'] = ...
        AUTOMATIC: typing.ClassVar['ModuleDescriptor.Modifier'] = ...
        SYNTHETIC: typing.ClassVar['ModuleDescriptor.Modifier'] = ...
        MANDATED: typing.ClassVar['ModuleDescriptor.Modifier'] = ...
        _valueOf_0__T = typing.TypeVar('_valueOf_0__T', bound=java.lang.Enum)  # <T>
        @typing.overload
        @staticmethod
        def valueOf(class_: typing.Type[_valueOf_0__T], string: str) -> _valueOf_0__T: ...
        @typing.overload
        @staticmethod
        def valueOf(string: str) -> 'ModuleDescriptor.Modifier': ...
        @staticmethod
        def values() -> typing.List['ModuleDescriptor.Modifier']: ...
    class Opens(java.lang.Comparable['ModuleDescriptor.Opens']):
        def compareTo(self, opens: 'ModuleDescriptor.Opens') -> int: ...
        def equals(self, object: typing.Any) -> bool: ...
        def hashCode(self) -> int: ...
        def isQualified(self) -> bool: ...
        def modifiers(self) -> java.util.Set['ModuleDescriptor.Opens.Modifier']: ...
        def source(self) -> str: ...
        def targets(self) -> java.util.Set[str]: ...
        def toString(self) -> str: ...
        class Modifier(java.lang.Enum['ModuleDescriptor.Opens.Modifier']):
            SYNTHETIC: typing.ClassVar['ModuleDescriptor.Opens.Modifier'] = ...
            MANDATED: typing.ClassVar['ModuleDescriptor.Opens.Modifier'] = ...
            _valueOf_0__T = typing.TypeVar('_valueOf_0__T', bound=java.lang.Enum)  # <T>
            @typing.overload
            @staticmethod
            def valueOf(class_: typing.Type[_valueOf_0__T], string: str) -> _valueOf_0__T: ...
            @typing.overload
            @staticmethod
            def valueOf(string: str) -> 'ModuleDescriptor.Opens.Modifier': ...
            @staticmethod
            def values() -> typing.List['ModuleDescriptor.Opens.Modifier']: ...
    class Provides(java.lang.Comparable['ModuleDescriptor.Provides']):
        def compareTo(self, provides: 'ModuleDescriptor.Provides') -> int: ...
        def equals(self, object: typing.Any) -> bool: ...
        def hashCode(self) -> int: ...
        def providers(self) -> java.util.List[str]: ...
        def service(self) -> str: ...
        def toString(self) -> str: ...
    class Requires(java.lang.Comparable['ModuleDescriptor.Requires']):
        def compareTo(self, requires: 'ModuleDescriptor.Requires') -> int: ...
        def compiledVersion(self) -> java.util.Optional['ModuleDescriptor.Version']: ...
        def equals(self, object: typing.Any) -> bool: ...
        def hashCode(self) -> int: ...
        def modifiers(self) -> java.util.Set['ModuleDescriptor.Requires.Modifier']: ...
        def name(self) -> str: ...
        def rawCompiledVersion(self) -> java.util.Optional[str]: ...
        def toString(self) -> str: ...
        class Modifier(java.lang.Enum['ModuleDescriptor.Requires.Modifier']):
            TRANSITIVE: typing.ClassVar['ModuleDescriptor.Requires.Modifier'] = ...
            STATIC: typing.ClassVar['ModuleDescriptor.Requires.Modifier'] = ...
            SYNTHETIC: typing.ClassVar['ModuleDescriptor.Requires.Modifier'] = ...
            MANDATED: typing.ClassVar['ModuleDescriptor.Requires.Modifier'] = ...
            _valueOf_0__T = typing.TypeVar('_valueOf_0__T', bound=java.lang.Enum)  # <T>
            @typing.overload
            @staticmethod
            def valueOf(class_: typing.Type[_valueOf_0__T], string: str) -> _valueOf_0__T: ...
            @typing.overload
            @staticmethod
            def valueOf(string: str) -> 'ModuleDescriptor.Requires.Modifier': ...
            @staticmethod
            def values() -> typing.List['ModuleDescriptor.Requires.Modifier']: ...
    class Version(java.lang.Comparable['ModuleDescriptor.Version']):
        def compareTo(self, version: 'ModuleDescriptor.Version') -> int: ...
        def equals(self, object: typing.Any) -> bool: ...
        def hashCode(self) -> int: ...
        @staticmethod
        def parse(string: str) -> 'ModuleDescriptor.Version': ...
        def toString(self) -> str: ...

class ModuleFinder:
    @staticmethod
    def compose(moduleFinderArray: typing.List['ModuleFinder']) -> 'ModuleFinder': ...
    def find(self, string: str) -> java.util.Optional['ModuleReference']: ...
    def findAll(self) -> java.util.Set['ModuleReference']: ...
    @staticmethod
    def of(pathArray: typing.List[java.nio.file.Path]) -> 'ModuleFinder': ...
    @staticmethod
    def ofSystem() -> 'ModuleFinder': ...

class ModuleReader(java.io.Closeable):
    def close(self) -> None: ...
    def find(self, string: str) -> java.util.Optional[java.net.URI]: ...
    def list(self) -> java.util.stream.Stream[str]: ...
    def open(self, string: str) -> java.util.Optional[java.io.InputStream]: ...
    def read(self, string: str) -> java.util.Optional[java.nio.ByteBuffer]: ...
    def release(self, byteBuffer: java.nio.ByteBuffer) -> None: ...

class ModuleReference:
    def descriptor(self) -> ModuleDescriptor: ...
    def location(self) -> java.util.Optional[java.net.URI]: ...
    def open(self) -> ModuleReader: ...

class ResolutionException(java.lang.RuntimeException):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, throwable: java.lang.Throwable): ...
    @typing.overload
    def __init__(self, throwable: java.lang.Throwable): ...

class ResolvedModule:
    def configuration(self) -> Configuration: ...
    def equals(self, object: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    def name(self) -> str: ...
    def reads(self) -> java.util.Set['ResolvedModule']: ...
    def reference(self) -> ModuleReference: ...
    def toString(self) -> str: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.lang.module")``.

    Configuration: typing.Type[Configuration]
    FindException: typing.Type[FindException]
    InvalidModuleDescriptorException: typing.Type[InvalidModuleDescriptorException]
    ModuleDescriptor: typing.Type[ModuleDescriptor]
    ModuleFinder: typing.Type[ModuleFinder]
    ModuleReader: typing.Type[ModuleReader]
    ModuleReference: typing.Type[ModuleReference]
    ResolutionException: typing.Type[ResolutionException]
    ResolvedModule: typing.Type[ResolvedModule]
